/*
 * DO NOT EDIT THIS FILE - it is generated by Glade.
 */

#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include <sys/types.h>
#include <sys/stat.h>
#include <unistd.h>
#include <string.h>
#include <stdio.h>

#include <gdk/gdkkeysyms.h>
#include <gtk/gtk.h>

#include "xo-callbacks.h"
#include "xo-interface.h"
#include "xo-support.h"

#define GLADE_HOOKUP_OBJECT(component,widget,name) \
  g_object_set_data_full (G_OBJECT (component), name, \
    gtk_widget_ref (widget), (GDestroyNotify) gtk_widget_unref)

#define GLADE_HOOKUP_OBJECT_NO_REF(component,widget,name) \
  g_object_set_data (G_OBJECT (component), name, widget)

GtkWidget*
create_winMain (void)
{
  GtkWidget *winMain;
  GtkWidget *vboxMain;
  GtkWidget *menubar;
  GtkWidget *menuFile;
  GtkWidget *menuFile_menu;
  GtkWidget *fileNew;
  GtkWidget *fileNewBackground;
  GtkWidget *image623;
  GtkWidget *fileOpen;
  GtkWidget *fileSave;
  GtkWidget *fileSaveAs;
  GtkWidget *separator1;
  GtkWidget *fileRecentFiles;
  GtkWidget *fileRecentFiles_menu;
  GtkWidget *mru0;
  GtkWidget *mru1;
  GtkWidget *mru2;
  GtkWidget *mru3;
  GtkWidget *mru4;
  GtkWidget *mru5;
  GtkWidget *mru6;
  GtkWidget *mru7;
  GtkWidget *separator22;
  GtkWidget *filePrintOptions;
  GtkWidget *image624;
  GtkWidget *filePrint;
  GtkWidget *filePrintPDF;
  GtkWidget *separator2;
  GtkWidget *fileQuit;
  GtkWidget *menuEdit;
  GtkWidget *menuEdit_menu;
  GtkWidget *editUndo;
  GtkWidget *editRedo;
  GtkWidget *separator3;
  GtkWidget *editCut;
  GtkWidget *editCopy;
  GtkWidget *editPaste;
  GtkWidget *editDelete;
  GtkWidget *menuView;
  GtkWidget *menuView_menu;
  GSList *viewContinuous_group = NULL;
  GtkWidget *viewContinuous;
  GtkWidget *viewHorizontal;
  GtkWidget *viewOnePage;
  GtkWidget *separator20;
  GtkWidget *viewFullscreen;
  GtkWidget *separator4;
  GtkWidget *menuViewZoom;
  GtkWidget *menuViewZoom_menu;
  GtkWidget *viewZoomIn;
  GtkWidget *viewZoomOut;
  GtkWidget *viewNormalSize;
  GtkWidget *viewPageWidth;
  GtkWidget *image625;
  GtkWidget *viewSetZoom;
  GtkWidget *separator5;
  GtkWidget *viewFirstPage;
  GtkWidget *image626;
  GtkWidget *viewPreviousPage;
  GtkWidget *image627;
  GtkWidget *viewNextPage;
  GtkWidget *image628;
  GtkWidget *viewLastPage;
  GtkWidget *image629;
  GtkWidget *separator6;
  GtkWidget *viewShowLayer;
  GtkWidget *image630;
  GtkWidget *viewHideLayer;
  GtkWidget *image631;
  GtkWidget *menuJournal;
  GtkWidget *menuJournal_menu;
  GtkWidget *journalNewPageBefore;
  GtkWidget *journalNewPageAfter;
  GtkWidget *journalNewPageEnd;
  GtkWidget *journalNewPageKeepsBG;
  GtkWidget *journalDeletePage;
  GtkWidget *separator7;
  GtkWidget *journalNewLayer;
  GtkWidget *journalDeleteLayer;
  GtkWidget *journalFlatten;
  GtkWidget *separator8;
  GtkWidget *journalPaperSize;
  GtkWidget *journalPaperColor;
  GtkWidget *journalPaperColor_menu;
  GSList *papercolorWhite_group = NULL;
  GtkWidget *papercolorWhite;
  GtkWidget *papercolorYellow;
  GtkWidget *papercolorPink;
  GtkWidget *papercolorOrange;
  GtkWidget *papercolorBlue;
  GtkWidget *papercolorGreen;
  GtkWidget *papercolorOther;
  GtkWidget *papercolorNA;
  GtkWidget *journalPaperStyle;
  GtkWidget *journalPaperStyle_menu;
  GSList *paperstylePlain_group = NULL;
  GtkWidget *paperstylePlain;
  GtkWidget *paperstyleLined;
  GtkWidget *paperstyleRuled;
  GtkWidget *paperstyleGraph;
  GtkWidget *paperstyleNA;
  GtkWidget *journalApplyAllPages;
  GtkWidget *separator23;
  GtkWidget *journalLoadBackground;
  GtkWidget *image632;
  GtkWidget *journalScreenshot;
  GtkWidget *separator19;
  GtkWidget *journalDefaultBackground;
  GtkWidget *journalSetAsDefault;
  GtkWidget *menuTools;
  GtkWidget *menuTools_menu;
  GSList *toolsPen_group = NULL;
  GtkWidget *toolsPen;
  GtkWidget *toolsEraser;
  GtkWidget *toolsHighlighter;
  GtkWidget *toolsText;
  GtkWidget *toolsImage;
  GtkWidget *separator15;
  GtkWidget *toolsReco;
  GtkWidget *toolsRuler;
  GtkWidget *separator9;
  GtkWidget *toolsSelectRegion;
  GtkWidget *toolsSelectRectangle;
  GtkWidget *toolsVerticalSpace;
  GtkWidget *toolsHand;
  GtkWidget *separator16;
  GtkWidget *toolsColor;
  GtkWidget *image633;
  GtkWidget *toolsColor_menu;
  GSList *colorBlack_group = NULL;
  GtkWidget *colorBlack;
  GtkWidget *colorBlue;
  GtkWidget *colorRed;
  GtkWidget *colorGreen;
  GtkWidget *colorGray;
  GtkWidget *separator17;
  GtkWidget *colorLightBlue;
  GtkWidget *colorLightGreen;
  GtkWidget *colorMagenta;
  GtkWidget *colorOrange;
  GtkWidget *colorYellow;
  GtkWidget *colorWhite;
  GtkWidget *colorOther;
  GtkWidget *colorNA;
  GtkWidget *toolsPenOptions;
  GtkWidget *toolsPenOptions_menu;
  GSList *penthicknessVeryFine_group = NULL;
  GtkWidget *penthicknessVeryFine;
  GtkWidget *penthicknessFine;
  GtkWidget *penthicknessMedium;
  GtkWidget *penthicknessThick;
  GtkWidget *penthicknessVeryThick;
  GtkWidget *toolsEraserOptions;
  GtkWidget *toolsEraserOptions_menu;
  GSList *eraserFine_group = NULL;
  GtkWidget *eraserFine;
  GtkWidget *eraserMedium;
  GtkWidget *eraserThick;
  GtkWidget *separator14;
  GSList *eraserStandard_group = NULL;
  GtkWidget *eraserStandard;
  GtkWidget *eraserWhiteout;
  GtkWidget *eraserDeleteStrokes;
  GtkWidget *toolsHighlighterOptions;
  GtkWidget *toolsHighlighterOptions_menu;
  GSList *highlighterFine_group = NULL;
  GtkWidget *highlighterFine;
  GtkWidget *highlighterMedium;
  GtkWidget *highlighterThick;
  GtkWidget *toolsTextFont;
  GtkWidget *image634;
  GtkWidget *separator10;
  GtkWidget *toolsDefaultPen;
  GtkWidget *toolsDefaultEraser;
  GtkWidget *toolsDefaultHighlighter;
  GtkWidget *toolsDefaultText;
  GtkWidget *toolsSetAsDefault;
  GtkWidget *menuOptions;
  GtkWidget *menuOptions_menu;
  GtkWidget *optionsUseXInput;
  GtkWidget *pen_and_touch;
  GtkWidget *pen_and_touch_menu;
  GtkWidget *optionsButtonMappings;
  GtkWidget *optionsPressureSensitive;
  GtkWidget *optionsButtonSwitchMapping;
  GtkWidget *optionsTouchAsHandTool;
  GtkWidget *optionsPenDisablesTouch;
  GtkWidget *optionsDesignateTouchscreen;
  GtkWidget *button2_mapping;
  GtkWidget *button2_mapping_menu;
  GSList *button2Pen_group = NULL;
  GtkWidget *button2Pen;
  GtkWidget *button2Eraser;
  GtkWidget *button2Highlighter;
  GtkWidget *button2Text;
  GtkWidget *button2Image;
  GtkWidget *button2SelectRegion;
  GtkWidget *button2SelectRectangle;
  GtkWidget *button2VerticalSpace;
  GtkWidget *button2Hand;
  GtkWidget *separator24;
  GSList *button2LinkBrush_group = NULL;
  GtkWidget *button2LinkBrush;
  GtkWidget *button2CopyBrush;
  GtkWidget *button2NABrush;
  GtkWidget *button3_mapping;
  GtkWidget *button3_mapping_menu;
  GSList *button3Pen_group = NULL;
  GtkWidget *button3Pen;
  GtkWidget *button3Eraser;
  GtkWidget *button3Highlighter;
  GtkWidget *button3Text;
  GtkWidget *button3Image;
  GtkWidget *button3SelectRegion;
  GtkWidget *button3SelectRectangle;
  GtkWidget *button3VerticalSpace;
  GtkWidget *button3Hand;
  GtkWidget *separator25;
  GSList *button3LinkBrush_group = NULL;
  GtkWidget *button3LinkBrush;
  GtkWidget *button3CopyBrush;
  GtkWidget *button3NABrush;
  GtkWidget *separator18;
  GtkWidget *optionsProgressiveBG;
  GtkWidget *optionsPrintRuling;
  GtkWidget *optionsLegacyPDFExport;
  GtkWidget *optionsLayersPDFExport;
  GtkWidget *optionsAutoloadPdfXoj;
  GtkWidget *optionsAutosaveXoj;
  GtkWidget *optionsLeftHanded;
  GtkWidget *optionsShortenMenus;
  GtkWidget *optionsPenCursor;
  GtkWidget *separator21;
  GtkWidget *optionsAutoSavePrefs;
  GtkWidget *optionsSavePreferences;
  GtkWidget *menuHelp;
  GtkWidget *menuHelp_menu;
  GtkWidget *helpIndex;
  GtkWidget *helpAbout;
  GtkWidget *toolbarMain;
  GtkIconSize tmp_toolbar_icon_size;
  GtkWidget *saveButton;
  GtkWidget *newButton;
  GtkWidget *openButton;
  GtkWidget *toolitem11;
  GtkWidget *vseparator1;
  GtkWidget *buttonCut;
  GtkWidget *buttonCopy;
  GtkWidget *buttonPaste;
  GtkWidget *toolitem12;
  GtkWidget *vseparator2;
  GtkWidget *buttonUndo;
  GtkWidget *buttonRedo;
  GtkWidget *toolitem13;
  GtkWidget *vseparator3;
  GtkWidget *buttonFirstPage;
  GtkWidget *buttonPreviousPage;
  GtkWidget *buttonNextPage;
  GtkWidget *buttonLastPage;
  GtkWidget *toolitem14;
  GtkWidget *vseparator4;
  GtkWidget *buttonZoomOut;
  GtkWidget *buttonPageWidth;
  GtkWidget *buttonZoomIn;
  GtkWidget *buttonNormalSize;
  GtkWidget *buttonZoomSet;
  GtkWidget *tmp_image;
  GtkWidget *buttonFullscreen;
  GtkWidget *toolbarPen;
  GSList *buttonPen_group = NULL;
  GtkWidget *buttonPen;
  GtkWidget *buttonEraser;
  GtkWidget *buttonHighlighter;
  GtkWidget *buttonText;
  GtkWidget *buttonImage;
  GtkWidget *buttonReco;
  GtkWidget *buttonRuler;
  GtkWidget *toolitem15;
  GtkWidget *vseparator5;
  GtkWidget *buttonSelectRegion;
  GtkWidget *buttonSelectRectangle;
  GtkWidget *buttonVerticalSpace;
  GtkWidget *buttonHand;
  GtkWidget *toolitem16;
  GtkWidget *vseparator6;
  GtkWidget *buttonToolDefault;
  GtkWidget *buttonDefaultPen;
  GtkWidget *toolitem18;
  GtkWidget *vseparator8;
  GSList *buttonFine_group = NULL;
  GtkWidget *buttonFine;
  GtkWidget *buttonMedium;
  GtkWidget *buttonThick;
  GtkWidget *buttonThicknessOther;
  GtkWidget *toolitem17;
  GtkWidget *vseparator7;
  GSList *buttonBlack_group = NULL;
  GtkWidget *buttonBlack;
  GtkWidget *buttonBlue;
  GtkWidget *buttonRed;
  GtkWidget *buttonGreen;
  GtkWidget *buttonGray;
  GtkWidget *buttonLightBlue;
  GtkWidget *buttonLightGreen;
  GtkWidget *buttonMagenta;
  GtkWidget *buttonOrange;
  GtkWidget *buttonYellow;
  GtkWidget *buttonWhite;
  GtkWidget *buttonColorOther;
  GtkWidget *toolitem22;
  GtkWidget *buttonColorChooser;
  GtkWidget *toolitem21;
  GtkWidget *vseparator10;
  GtkWidget *toolitem20;
  GtkWidget *fontButton;
  GtkWidget *scrolledwindowMain;
  GtkWidget *hbox1;
  GtkWidget *labelPage;
  GtkObject *spinPageNo_adj;
  GtkWidget *spinPageNo;
  GtkWidget *labelNumpages;
  GtkWidget *vseparator9;
  GtkWidget *labelLayer;
  GtkWidget *comboLayer;
  GtkWidget *statusbar;
  GtkAccelGroup *accel_group;
  GtkTooltips *tooltips;

  tooltips = gtk_tooltips_new ();

  accel_group = gtk_accel_group_new ();

  winMain = gtk_window_new (GTK_WINDOW_TOPLEVEL);
  gtk_window_set_title (GTK_WINDOW (winMain), _("Xournal"));

  vboxMain = gtk_vbox_new (FALSE, 0);
  gtk_widget_show (vboxMain);
  gtk_container_add (GTK_CONTAINER (winMain), vboxMain);

  menubar = gtk_menu_bar_new ();
  gtk_widget_show (menubar);
  gtk_box_pack_start (GTK_BOX (vboxMain), menubar, FALSE, FALSE, 0);

  menuFile = gtk_menu_item_new_with_mnemonic (_("_File"));
  gtk_widget_show (menuFile);
  gtk_container_add (GTK_CONTAINER (menubar), menuFile);

  menuFile_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuFile), menuFile_menu);

  fileNew = gtk_image_menu_item_new_from_stock ("gtk-new", accel_group);
  gtk_widget_show (fileNew);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), fileNew);

  fileNewBackground = gtk_image_menu_item_new_with_mnemonic (_("Annotate PD_F"));
  gtk_widget_show (fileNewBackground);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), fileNewBackground);

  image623 = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image623);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (fileNewBackground), image623);

  fileOpen = gtk_image_menu_item_new_from_stock ("gtk-open", accel_group);
  gtk_widget_show (fileOpen);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), fileOpen);

  fileSave = gtk_image_menu_item_new_from_stock ("gtk-save", accel_group);
  gtk_widget_show (fileSave);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), fileSave);

  fileSaveAs = gtk_image_menu_item_new_from_stock ("gtk-save-as", accel_group);
  gtk_widget_show (fileSaveAs);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), fileSaveAs);

  separator1 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator1);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), separator1);
  gtk_widget_set_sensitive (separator1, FALSE);

  fileRecentFiles = gtk_menu_item_new_with_mnemonic (_("Recent Doc_uments"));
  gtk_widget_show (fileRecentFiles);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), fileRecentFiles);

  fileRecentFiles_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (fileRecentFiles), fileRecentFiles_menu);

  mru0 = gtk_menu_item_new_with_mnemonic (_("0"));
  gtk_widget_show (mru0);
  gtk_container_add (GTK_CONTAINER (fileRecentFiles_menu), mru0);

  mru1 = gtk_menu_item_new_with_mnemonic (_("1"));
  gtk_widget_show (mru1);
  gtk_container_add (GTK_CONTAINER (fileRecentFiles_menu), mru1);

  mru2 = gtk_menu_item_new_with_mnemonic (_("2"));
  gtk_widget_show (mru2);
  gtk_container_add (GTK_CONTAINER (fileRecentFiles_menu), mru2);

  mru3 = gtk_menu_item_new_with_mnemonic (_("3"));
  gtk_widget_show (mru3);
  gtk_container_add (GTK_CONTAINER (fileRecentFiles_menu), mru3);

  mru4 = gtk_menu_item_new_with_mnemonic (_("4"));
  gtk_widget_show (mru4);
  gtk_container_add (GTK_CONTAINER (fileRecentFiles_menu), mru4);

  mru5 = gtk_menu_item_new_with_mnemonic (_("5"));
  gtk_widget_show (mru5);
  gtk_container_add (GTK_CONTAINER (fileRecentFiles_menu), mru5);

  mru6 = gtk_menu_item_new_with_mnemonic (_("6"));
  gtk_widget_show (mru6);
  gtk_container_add (GTK_CONTAINER (fileRecentFiles_menu), mru6);

  mru7 = gtk_menu_item_new_with_mnemonic (_("7"));
  gtk_widget_show (mru7);
  gtk_container_add (GTK_CONTAINER (fileRecentFiles_menu), mru7);

  separator22 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator22);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), separator22);
  gtk_widget_set_sensitive (separator22, FALSE);

  filePrintOptions = gtk_image_menu_item_new_with_mnemonic (_("Print Options"));
  gtk_widget_show (filePrintOptions);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), filePrintOptions);

  image624 = gtk_image_new_from_stock ("gtk-preferences", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image624);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (filePrintOptions), image624);

  filePrint = gtk_image_menu_item_new_from_stock ("gtk-print", accel_group);
  gtk_widget_show (filePrint);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), filePrint);
  gtk_widget_add_accelerator (filePrint, "activate", accel_group,
                              GDK_P, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  filePrintPDF = gtk_menu_item_new_with_mnemonic (_("_Export to PDF"));
  gtk_widget_show (filePrintPDF);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), filePrintPDF);
  gtk_widget_add_accelerator (filePrintPDF, "activate", accel_group,
                              GDK_E, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  separator2 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator2);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), separator2);
  gtk_widget_set_sensitive (separator2, FALSE);

  fileQuit = gtk_image_menu_item_new_from_stock ("gtk-quit", accel_group);
  gtk_widget_show (fileQuit);
  gtk_container_add (GTK_CONTAINER (menuFile_menu), fileQuit);

  menuEdit = gtk_menu_item_new_with_mnemonic (_("_Edit"));
  gtk_widget_show (menuEdit);
  gtk_container_add (GTK_CONTAINER (menubar), menuEdit);

  menuEdit_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuEdit), menuEdit_menu);

  editUndo = gtk_image_menu_item_new_from_stock ("gtk-undo", accel_group);
  gtk_widget_show (editUndo);
  gtk_container_add (GTK_CONTAINER (menuEdit_menu), editUndo);
  gtk_widget_add_accelerator (editUndo, "activate", accel_group,
                              GDK_Z, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  editRedo = gtk_image_menu_item_new_from_stock ("gtk-redo", accel_group);
  gtk_widget_show (editRedo);
  gtk_container_add (GTK_CONTAINER (menuEdit_menu), editRedo);
  gtk_widget_add_accelerator (editRedo, "activate", accel_group,
                              GDK_Y, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  separator3 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator3);
  gtk_container_add (GTK_CONTAINER (menuEdit_menu), separator3);
  gtk_widget_set_sensitive (separator3, FALSE);

  editCut = gtk_image_menu_item_new_from_stock ("gtk-cut", accel_group);
  gtk_widget_show (editCut);
  gtk_container_add (GTK_CONTAINER (menuEdit_menu), editCut);

  editCopy = gtk_image_menu_item_new_from_stock ("gtk-copy", accel_group);
  gtk_widget_show (editCopy);
  gtk_container_add (GTK_CONTAINER (menuEdit_menu), editCopy);

  editPaste = gtk_image_menu_item_new_from_stock ("gtk-paste", accel_group);
  gtk_widget_show (editPaste);
  gtk_container_add (GTK_CONTAINER (menuEdit_menu), editPaste);

  editDelete = gtk_image_menu_item_new_from_stock ("gtk-delete", accel_group);
  gtk_widget_show (editDelete);
  gtk_container_add (GTK_CONTAINER (menuEdit_menu), editDelete);
  gtk_widget_add_accelerator (editDelete, "activate", accel_group,
                              GDK_Delete, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  menuView = gtk_menu_item_new_with_mnemonic (_("_View"));
  gtk_widget_show (menuView);
  gtk_container_add (GTK_CONTAINER (menubar), menuView);

  menuView_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuView), menuView_menu);

  viewContinuous = gtk_radio_menu_item_new_with_mnemonic (viewContinuous_group, _("_Continuous"));
  viewContinuous_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (viewContinuous));
  gtk_widget_show (viewContinuous);
  gtk_container_add (GTK_CONTAINER (menuView_menu), viewContinuous);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (viewContinuous), TRUE);

  viewHorizontal = gtk_radio_menu_item_new_with_mnemonic (viewContinuous_group, _("Horizontal"));
  viewContinuous_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (viewHorizontal));
  gtk_widget_show (viewHorizontal);
  gtk_container_add (GTK_CONTAINER (menuView_menu), viewHorizontal);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (viewHorizontal), TRUE);

  viewOnePage = gtk_radio_menu_item_new_with_mnemonic (viewContinuous_group, _("_One Page"));
  viewContinuous_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (viewOnePage));
  gtk_widget_show (viewOnePage);
  gtk_container_add (GTK_CONTAINER (menuView_menu), viewOnePage);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (viewOnePage), TRUE);

  separator20 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator20);
  gtk_container_add (GTK_CONTAINER (menuView_menu), separator20);
  gtk_widget_set_sensitive (separator20, FALSE);

  viewFullscreen = gtk_check_menu_item_new_with_mnemonic (_("Full Screen"));
  gtk_widget_show (viewFullscreen);
  gtk_container_add (GTK_CONTAINER (menuView_menu), viewFullscreen);
  gtk_widget_add_accelerator (viewFullscreen, "activate", accel_group,
                              GDK_F11, (GdkModifierType) 0,
                              GTK_ACCEL_VISIBLE);

  separator4 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator4);
  gtk_container_add (GTK_CONTAINER (menuView_menu), separator4);
  gtk_widget_set_sensitive (separator4, FALSE);

  menuViewZoom = gtk_menu_item_new_with_mnemonic (_("_Zoom"));
  gtk_widget_show (menuViewZoom);
  gtk_container_add (GTK_CONTAINER (menuView_menu), menuViewZoom);

  menuViewZoom_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuViewZoom), menuViewZoom_menu);

  viewZoomIn = gtk_image_menu_item_new_from_stock ("gtk-zoom-in", accel_group);
  gtk_widget_show (viewZoomIn);
  gtk_container_add (GTK_CONTAINER (menuViewZoom_menu), viewZoomIn);
  gtk_widget_add_accelerator (viewZoomIn, "activate", accel_group,
                              GDK_plus, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  viewZoomOut = gtk_image_menu_item_new_from_stock ("gtk-zoom-out", accel_group);
  gtk_widget_show (viewZoomOut);
  gtk_container_add (GTK_CONTAINER (menuViewZoom_menu), viewZoomOut);
  gtk_widget_add_accelerator (viewZoomOut, "activate", accel_group,
                              GDK_minus, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  viewNormalSize = gtk_image_menu_item_new_from_stock ("gtk-zoom-100", accel_group);
  gtk_widget_show (viewNormalSize);
  gtk_container_add (GTK_CONTAINER (menuViewZoom_menu), viewNormalSize);
  gtk_widget_add_accelerator (viewNormalSize, "activate", accel_group,
                              GDK_0, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  viewPageWidth = gtk_image_menu_item_new_with_mnemonic (_("Page _Width"));
  gtk_widget_show (viewPageWidth);
  gtk_container_add (GTK_CONTAINER (menuViewZoom_menu), viewPageWidth);
  gtk_widget_add_accelerator (viewPageWidth, "activate", accel_group,
                              GDK_equal, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image625 = gtk_image_new_from_stock ("gtk-zoom-fit", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image625);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (viewPageWidth), image625);

  viewSetZoom = gtk_menu_item_new_with_mnemonic (_("_Set Zoom"));
  gtk_widget_show (viewSetZoom);
  gtk_container_add (GTK_CONTAINER (menuViewZoom_menu), viewSetZoom);

  separator5 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator5);
  gtk_container_add (GTK_CONTAINER (menuView_menu), separator5);
  gtk_widget_set_sensitive (separator5, FALSE);

  viewFirstPage = gtk_image_menu_item_new_with_mnemonic (_("_First Page"));
  gtk_widget_show (viewFirstPage);
  gtk_container_add (GTK_CONTAINER (menuView_menu), viewFirstPage);
  gtk_widget_add_accelerator (viewFirstPage, "activate", accel_group,
                              GDK_Home, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image626 = gtk_image_new_from_stock ("gtk-goto-first", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image626);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (viewFirstPage), image626);

  viewPreviousPage = gtk_image_menu_item_new_with_mnemonic (_("_Previous Page"));
  gtk_widget_show (viewPreviousPage);
  gtk_container_add (GTK_CONTAINER (menuView_menu), viewPreviousPage);
  gtk_widget_add_accelerator (viewPreviousPage, "activate", accel_group,
                              GDK_Left, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image627 = gtk_image_new_from_stock ("gtk-go-back", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image627);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (viewPreviousPage), image627);

  viewNextPage = gtk_image_menu_item_new_with_mnemonic (_("_Next Page"));
  gtk_widget_show (viewNextPage);
  gtk_container_add (GTK_CONTAINER (menuView_menu), viewNextPage);
  gtk_widget_add_accelerator (viewNextPage, "activate", accel_group,
                              GDK_Right, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image628 = gtk_image_new_from_stock ("gtk-go-forward", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image628);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (viewNextPage), image628);

  viewLastPage = gtk_image_menu_item_new_with_mnemonic (_("_Last Page"));
  gtk_widget_show (viewLastPage);
  gtk_container_add (GTK_CONTAINER (menuView_menu), viewLastPage);
  gtk_widget_add_accelerator (viewLastPage, "activate", accel_group,
                              GDK_End, (GdkModifierType) GDK_CONTROL_MASK,
                              GTK_ACCEL_VISIBLE);

  image629 = gtk_image_new_from_stock ("gtk-goto-last", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image629);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (viewLastPage), image629);

  separator6 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator6);
  gtk_container_add (GTK_CONTAINER (menuView_menu), separator6);
  gtk_widget_set_sensitive (separator6, FALSE);

  viewShowLayer = gtk_image_menu_item_new_with_mnemonic (_("_Show Layer"));
  gtk_widget_show (viewShowLayer);
  gtk_container_add (GTK_CONTAINER (menuView_menu), viewShowLayer);

  image630 = gtk_image_new_from_stock ("gtk-add", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image630);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (viewShowLayer), image630);

  viewHideLayer = gtk_image_menu_item_new_with_mnemonic (_("_Hide Layer"));
  gtk_widget_show (viewHideLayer);
  gtk_container_add (GTK_CONTAINER (menuView_menu), viewHideLayer);

  image631 = gtk_image_new_from_stock ("gtk-remove", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image631);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (viewHideLayer), image631);

  menuJournal = gtk_menu_item_new_with_mnemonic (_("_Page"));
  gtk_widget_show (menuJournal);
  gtk_container_add (GTK_CONTAINER (menubar), menuJournal);

  menuJournal_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuJournal), menuJournal_menu);

  journalNewPageBefore = gtk_menu_item_new_with_mnemonic (_("New Page _Before"));
  gtk_widget_show (journalNewPageBefore);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalNewPageBefore);

  journalNewPageAfter = gtk_menu_item_new_with_mnemonic (_("New Page _After"));
  gtk_widget_show (journalNewPageAfter);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalNewPageAfter);

  journalNewPageEnd = gtk_menu_item_new_with_mnemonic (_("New Page At _End"));
  gtk_widget_show (journalNewPageEnd);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalNewPageEnd);

  journalNewPageKeepsBG = gtk_check_menu_item_new_with_mnemonic (_("New Pages Keep Background"));
  gtk_widget_show (journalNewPageKeepsBG);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalNewPageKeepsBG);

  journalDeletePage = gtk_menu_item_new_with_mnemonic (_("_Delete Page"));
  gtk_widget_show (journalDeletePage);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalDeletePage);

  separator7 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator7);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), separator7);
  gtk_widget_set_sensitive (separator7, FALSE);

  journalNewLayer = gtk_menu_item_new_with_mnemonic (_("_New Layer"));
  gtk_widget_show (journalNewLayer);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalNewLayer);

  journalDeleteLayer = gtk_menu_item_new_with_mnemonic (_("Delete La_yer"));
  gtk_widget_show (journalDeleteLayer);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalDeleteLayer);

  journalFlatten = gtk_menu_item_new_with_mnemonic (_("_Flatten"));
  gtk_widget_show (journalFlatten);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalFlatten);

  separator8 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator8);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), separator8);
  gtk_widget_set_sensitive (separator8, FALSE);

  journalPaperSize = gtk_menu_item_new_with_mnemonic (_("Paper Si_ze"));
  gtk_widget_show (journalPaperSize);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalPaperSize);

  journalPaperColor = gtk_menu_item_new_with_mnemonic (_("Paper _Color"));
  gtk_widget_show (journalPaperColor);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalPaperColor);

  journalPaperColor_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (journalPaperColor), journalPaperColor_menu);

  papercolorWhite = gtk_radio_menu_item_new_with_mnemonic (papercolorWhite_group, _("_white paper"));
  papercolorWhite_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (papercolorWhite));
  gtk_widget_show (papercolorWhite);
  gtk_container_add (GTK_CONTAINER (journalPaperColor_menu), papercolorWhite);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (papercolorWhite), TRUE);

  papercolorYellow = gtk_radio_menu_item_new_with_mnemonic (papercolorWhite_group, _("_yellow paper"));
  papercolorWhite_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (papercolorYellow));
  gtk_widget_show (papercolorYellow);
  gtk_container_add (GTK_CONTAINER (journalPaperColor_menu), papercolorYellow);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (papercolorYellow), TRUE);

  papercolorPink = gtk_radio_menu_item_new_with_mnemonic (papercolorWhite_group, _("_pink paper"));
  papercolorWhite_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (papercolorPink));
  gtk_widget_show (papercolorPink);
  gtk_container_add (GTK_CONTAINER (journalPaperColor_menu), papercolorPink);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (papercolorPink), TRUE);

  papercolorOrange = gtk_radio_menu_item_new_with_mnemonic (papercolorWhite_group, _("_orange paper"));
  papercolorWhite_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (papercolorOrange));
  gtk_widget_show (papercolorOrange);
  gtk_container_add (GTK_CONTAINER (journalPaperColor_menu), papercolorOrange);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (papercolorOrange), TRUE);

  papercolorBlue = gtk_radio_menu_item_new_with_mnemonic (papercolorWhite_group, _("_blue paper"));
  papercolorWhite_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (papercolorBlue));
  gtk_widget_show (papercolorBlue);
  gtk_container_add (GTK_CONTAINER (journalPaperColor_menu), papercolorBlue);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (papercolorBlue), TRUE);

  papercolorGreen = gtk_radio_menu_item_new_with_mnemonic (papercolorWhite_group, _("_green paper"));
  papercolorWhite_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (papercolorGreen));
  gtk_widget_show (papercolorGreen);
  gtk_container_add (GTK_CONTAINER (journalPaperColor_menu), papercolorGreen);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (papercolorGreen), TRUE);

  papercolorOther = gtk_menu_item_new_with_mnemonic (_("other..."));
  gtk_widget_show (papercolorOther);
  gtk_container_add (GTK_CONTAINER (journalPaperColor_menu), papercolorOther);

  papercolorNA = gtk_radio_menu_item_new_with_mnemonic (papercolorWhite_group, _("NA"));
  papercolorWhite_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (papercolorNA));
  gtk_container_add (GTK_CONTAINER (journalPaperColor_menu), papercolorNA);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (papercolorNA), TRUE);

  journalPaperStyle = gtk_menu_item_new_with_mnemonic (_("Paper _Style"));
  gtk_widget_show (journalPaperStyle);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalPaperStyle);

  journalPaperStyle_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (journalPaperStyle), journalPaperStyle_menu);

  paperstylePlain = gtk_radio_menu_item_new_with_mnemonic (paperstylePlain_group, _("_plain"));
  paperstylePlain_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (paperstylePlain));
  gtk_widget_show (paperstylePlain);
  gtk_container_add (GTK_CONTAINER (journalPaperStyle_menu), paperstylePlain);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (paperstylePlain), TRUE);

  paperstyleLined = gtk_radio_menu_item_new_with_mnemonic (paperstylePlain_group, _("_lined"));
  paperstylePlain_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (paperstyleLined));
  gtk_widget_show (paperstyleLined);
  gtk_container_add (GTK_CONTAINER (journalPaperStyle_menu), paperstyleLined);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (paperstyleLined), TRUE);

  paperstyleRuled = gtk_radio_menu_item_new_with_mnemonic (paperstylePlain_group, _("_ruled"));
  paperstylePlain_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (paperstyleRuled));
  gtk_widget_show (paperstyleRuled);
  gtk_container_add (GTK_CONTAINER (journalPaperStyle_menu), paperstyleRuled);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (paperstyleRuled), TRUE);

  paperstyleGraph = gtk_radio_menu_item_new_with_mnemonic (paperstylePlain_group, _("_graph"));
  paperstylePlain_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (paperstyleGraph));
  gtk_widget_show (paperstyleGraph);
  gtk_container_add (GTK_CONTAINER (journalPaperStyle_menu), paperstyleGraph);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (paperstyleGraph), TRUE);

  paperstyleNA = gtk_radio_menu_item_new_with_mnemonic (paperstylePlain_group, _("NA"));
  paperstylePlain_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (paperstyleNA));
  gtk_container_add (GTK_CONTAINER (journalPaperStyle_menu), paperstyleNA);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (paperstyleNA), TRUE);

  journalApplyAllPages = gtk_check_menu_item_new_with_mnemonic (_("Apply _To All Pages"));
  gtk_widget_show (journalApplyAllPages);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalApplyAllPages);

  separator23 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator23);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), separator23);
  gtk_widget_set_sensitive (separator23, FALSE);

  journalLoadBackground = gtk_image_menu_item_new_with_mnemonic (_("_Load Background"));
  gtk_widget_show (journalLoadBackground);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalLoadBackground);

  image632 = gtk_image_new_from_stock ("gtk-open", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image632);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (journalLoadBackground), image632);

  journalScreenshot = gtk_menu_item_new_with_mnemonic (_("Background Screens_hot"));
  gtk_widget_show (journalScreenshot);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalScreenshot);

  separator19 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator19);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), separator19);
  gtk_widget_set_sensitive (separator19, FALSE);

  journalDefaultBackground = gtk_menu_item_new_with_mnemonic (_("Default _Paper"));
  gtk_widget_show (journalDefaultBackground);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalDefaultBackground);

  journalSetAsDefault = gtk_menu_item_new_with_mnemonic (_("Set As De_fault"));
  gtk_widget_show (journalSetAsDefault);
  gtk_container_add (GTK_CONTAINER (menuJournal_menu), journalSetAsDefault);

  menuTools = gtk_menu_item_new_with_mnemonic (_("_Tools"));
  gtk_widget_show (menuTools);
  gtk_container_add (GTK_CONTAINER (menubar), menuTools);

  menuTools_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuTools), menuTools_menu);

  toolsPen = gtk_radio_menu_item_new_with_mnemonic (toolsPen_group, _("_Pen"));
  toolsPen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (toolsPen));
  gtk_widget_show (toolsPen);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsPen);
  gtk_widget_add_accelerator (toolsPen, "activate", accel_group,
                              GDK_P, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (toolsPen), TRUE);

  toolsEraser = gtk_radio_menu_item_new_with_mnemonic (toolsPen_group, _("_Eraser"));
  toolsPen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (toolsEraser));
  gtk_widget_show (toolsEraser);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsEraser);
  gtk_widget_add_accelerator (toolsEraser, "activate", accel_group,
                              GDK_E, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (toolsEraser), TRUE);

  toolsHighlighter = gtk_radio_menu_item_new_with_mnemonic (toolsPen_group, _("_Highlighter"));
  toolsPen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (toolsHighlighter));
  gtk_widget_show (toolsHighlighter);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsHighlighter);
  gtk_widget_add_accelerator (toolsHighlighter, "activate", accel_group,
                              GDK_H, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (toolsHighlighter), TRUE);

  toolsText = gtk_radio_menu_item_new_with_mnemonic (toolsPen_group, _("_Text"));
  toolsPen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (toolsText));
  gtk_widget_show (toolsText);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsText);
  gtk_widget_add_accelerator (toolsText, "activate", accel_group,
                              GDK_T, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (toolsText), TRUE);

  toolsImage = gtk_radio_menu_item_new_with_mnemonic (toolsPen_group, _("_Image"));
  toolsPen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (toolsImage));
  gtk_widget_show (toolsImage);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsImage);
  gtk_widget_add_accelerator (toolsImage, "activate", accel_group,
                              GDK_I, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (toolsImage), TRUE);

  separator15 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator15);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), separator15);
  gtk_widget_set_sensitive (separator15, FALSE);

  toolsReco = gtk_check_menu_item_new_with_mnemonic (_("_Shape Recognizer"));
  gtk_widget_show (toolsReco);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsReco);
  gtk_widget_add_accelerator (toolsReco, "activate", accel_group,
                              GDK_S, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);

  toolsRuler = gtk_check_menu_item_new_with_mnemonic (_("Ru_ler"));
  gtk_widget_show (toolsRuler);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsRuler);
  gtk_widget_add_accelerator (toolsRuler, "activate", accel_group,
                              GDK_L, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);

  separator9 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator9);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), separator9);
  gtk_widget_set_sensitive (separator9, FALSE);

  toolsSelectRegion = gtk_radio_menu_item_new_with_mnemonic (toolsPen_group, _("Select Re_gion"));
  toolsPen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (toolsSelectRegion));
  gtk_widget_show (toolsSelectRegion);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsSelectRegion);
  gtk_widget_add_accelerator (toolsSelectRegion, "activate", accel_group,
                              GDK_G, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (toolsSelectRegion), TRUE);

  toolsSelectRectangle = gtk_radio_menu_item_new_with_mnemonic (toolsPen_group, _("Select _Rectangle"));
  toolsPen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (toolsSelectRectangle));
  gtk_widget_show (toolsSelectRectangle);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsSelectRectangle);
  gtk_widget_add_accelerator (toolsSelectRectangle, "activate", accel_group,
                              GDK_R, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (toolsSelectRectangle), TRUE);

  toolsVerticalSpace = gtk_radio_menu_item_new_with_mnemonic (toolsPen_group, _("_Vertical Space"));
  toolsPen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (toolsVerticalSpace));
  gtk_widget_show (toolsVerticalSpace);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsVerticalSpace);
  gtk_widget_add_accelerator (toolsVerticalSpace, "activate", accel_group,
                              GDK_V, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (toolsVerticalSpace), TRUE);

  toolsHand = gtk_radio_menu_item_new_with_mnemonic (toolsPen_group, _("H_and Tool"));
  toolsPen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (toolsHand));
  gtk_widget_show (toolsHand);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsHand);
  gtk_widget_add_accelerator (toolsHand, "activate", accel_group,
                              GDK_A, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);

  separator16 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator16);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), separator16);
  gtk_widget_set_sensitive (separator16, FALSE);

  toolsColor = gtk_image_menu_item_new_with_mnemonic (_("_Color"));
  gtk_widget_show (toolsColor);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsColor);

  image633 = gtk_image_new_from_stock ("gtk-select-color", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image633);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (toolsColor), image633);

  toolsColor_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (toolsColor), toolsColor_menu);

  colorBlack = gtk_radio_menu_item_new_with_mnemonic (colorBlack_group, _("blac_k"));
  colorBlack_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (colorBlack));
  gtk_widget_show (colorBlack);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorBlack);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (colorBlack), TRUE);

  colorBlue = gtk_radio_menu_item_new_with_mnemonic (colorBlack_group, _("_blue"));
  colorBlack_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (colorBlue));
  gtk_widget_show (colorBlue);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorBlue);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (colorBlue), TRUE);

  colorRed = gtk_radio_menu_item_new_with_mnemonic (colorBlack_group, _("_red"));
  colorBlack_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (colorRed));
  gtk_widget_show (colorRed);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorRed);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (colorRed), TRUE);

  colorGreen = gtk_radio_menu_item_new_with_mnemonic (colorBlack_group, _("_green"));
  colorBlack_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (colorGreen));
  gtk_widget_show (colorGreen);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorGreen);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (colorGreen), TRUE);

  colorGray = gtk_radio_menu_item_new_with_mnemonic (colorBlack_group, _("gr_ay"));
  colorBlack_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (colorGray));
  gtk_widget_show (colorGray);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorGray);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (colorGray), TRUE);

  separator17 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator17);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), separator17);
  gtk_widget_set_sensitive (separator17, FALSE);

  colorLightBlue = gtk_radio_menu_item_new_with_mnemonic (colorBlack_group, _("light bl_ue"));
  colorBlack_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (colorLightBlue));
  gtk_widget_show (colorLightBlue);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorLightBlue);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (colorLightBlue), TRUE);

  colorLightGreen = gtk_radio_menu_item_new_with_mnemonic (colorBlack_group, _("light gr_een"));
  colorBlack_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (colorLightGreen));
  gtk_widget_show (colorLightGreen);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorLightGreen);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (colorLightGreen), TRUE);

  colorMagenta = gtk_radio_menu_item_new_with_mnemonic (colorBlack_group, _("_magenta"));
  colorBlack_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (colorMagenta));
  gtk_widget_show (colorMagenta);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorMagenta);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (colorMagenta), TRUE);

  colorOrange = gtk_radio_menu_item_new_with_mnemonic (colorBlack_group, _("_orange"));
  colorBlack_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (colorOrange));
  gtk_widget_show (colorOrange);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorOrange);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (colorOrange), TRUE);

  colorYellow = gtk_radio_menu_item_new_with_mnemonic (colorBlack_group, _("_yellow"));
  colorBlack_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (colorYellow));
  gtk_widget_show (colorYellow);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorYellow);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (colorYellow), TRUE);

  colorWhite = gtk_radio_menu_item_new_with_mnemonic (colorBlack_group, _("_white"));
  colorBlack_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (colorWhite));
  gtk_widget_show (colorWhite);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorWhite);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (colorWhite), TRUE);

  colorOther = gtk_menu_item_new_with_mnemonic (_("other..."));
  gtk_widget_show (colorOther);
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorOther);

  colorNA = gtk_radio_menu_item_new_with_mnemonic (colorBlack_group, _("NA"));
  colorBlack_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (colorNA));
  gtk_container_add (GTK_CONTAINER (toolsColor_menu), colorNA);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (colorNA), TRUE);

  toolsPenOptions = gtk_menu_item_new_with_mnemonic (_("Pen _Options"));
  gtk_widget_show (toolsPenOptions);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsPenOptions);

  toolsPenOptions_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (toolsPenOptions), toolsPenOptions_menu);

  penthicknessVeryFine = gtk_radio_menu_item_new_with_mnemonic (penthicknessVeryFine_group, _("_very fine"));
  penthicknessVeryFine_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (penthicknessVeryFine));
  gtk_widget_show (penthicknessVeryFine);
  gtk_container_add (GTK_CONTAINER (toolsPenOptions_menu), penthicknessVeryFine);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (penthicknessVeryFine), TRUE);

  penthicknessFine = gtk_radio_menu_item_new_with_mnemonic (penthicknessVeryFine_group, _("_fine"));
  penthicknessVeryFine_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (penthicknessFine));
  gtk_widget_show (penthicknessFine);
  gtk_container_add (GTK_CONTAINER (toolsPenOptions_menu), penthicknessFine);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (penthicknessFine), TRUE);

  penthicknessMedium = gtk_radio_menu_item_new_with_mnemonic (penthicknessVeryFine_group, _("_medium"));
  penthicknessVeryFine_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (penthicknessMedium));
  gtk_widget_show (penthicknessMedium);
  gtk_container_add (GTK_CONTAINER (toolsPenOptions_menu), penthicknessMedium);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (penthicknessMedium), TRUE);

  penthicknessThick = gtk_radio_menu_item_new_with_mnemonic (penthicknessVeryFine_group, _("_thick"));
  penthicknessVeryFine_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (penthicknessThick));
  gtk_widget_show (penthicknessThick);
  gtk_container_add (GTK_CONTAINER (toolsPenOptions_menu), penthicknessThick);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (penthicknessThick), TRUE);

  penthicknessVeryThick = gtk_radio_menu_item_new_with_mnemonic (penthicknessVeryFine_group, _("ver_y thick"));
  penthicknessVeryFine_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (penthicknessVeryThick));
  gtk_widget_show (penthicknessVeryThick);
  gtk_container_add (GTK_CONTAINER (toolsPenOptions_menu), penthicknessVeryThick);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (penthicknessVeryThick), TRUE);

  toolsEraserOptions = gtk_menu_item_new_with_mnemonic (_("Eraser Optio_ns"));
  gtk_widget_show (toolsEraserOptions);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsEraserOptions);

  toolsEraserOptions_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (toolsEraserOptions), toolsEraserOptions_menu);

  eraserFine = gtk_radio_menu_item_new_with_mnemonic (eraserFine_group, _("_fine"));
  eraserFine_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (eraserFine));
  gtk_widget_show (eraserFine);
  gtk_container_add (GTK_CONTAINER (toolsEraserOptions_menu), eraserFine);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (eraserFine), TRUE);

  eraserMedium = gtk_radio_menu_item_new_with_mnemonic (eraserFine_group, _("_medium"));
  eraserFine_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (eraserMedium));
  gtk_widget_show (eraserMedium);
  gtk_container_add (GTK_CONTAINER (toolsEraserOptions_menu), eraserMedium);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (eraserMedium), TRUE);

  eraserThick = gtk_radio_menu_item_new_with_mnemonic (eraserFine_group, _("_thick"));
  eraserFine_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (eraserThick));
  gtk_widget_show (eraserThick);
  gtk_container_add (GTK_CONTAINER (toolsEraserOptions_menu), eraserThick);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (eraserThick), TRUE);

  separator14 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator14);
  gtk_container_add (GTK_CONTAINER (toolsEraserOptions_menu), separator14);
  gtk_widget_set_sensitive (separator14, FALSE);

  eraserStandard = gtk_radio_menu_item_new_with_mnemonic (eraserStandard_group, _("_standard"));
  eraserStandard_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (eraserStandard));
  gtk_widget_show (eraserStandard);
  gtk_container_add (GTK_CONTAINER (toolsEraserOptions_menu), eraserStandard);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (eraserStandard), TRUE);

  eraserWhiteout = gtk_radio_menu_item_new_with_mnemonic (eraserStandard_group, _("_whiteout"));
  eraserStandard_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (eraserWhiteout));
  gtk_widget_show (eraserWhiteout);
  gtk_container_add (GTK_CONTAINER (toolsEraserOptions_menu), eraserWhiteout);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (eraserWhiteout), TRUE);

  eraserDeleteStrokes = gtk_radio_menu_item_new_with_mnemonic (eraserStandard_group, _("_delete strokes"));
  eraserStandard_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (eraserDeleteStrokes));
  gtk_widget_show (eraserDeleteStrokes);
  gtk_container_add (GTK_CONTAINER (toolsEraserOptions_menu), eraserDeleteStrokes);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (eraserDeleteStrokes), TRUE);

  toolsHighlighterOptions = gtk_menu_item_new_with_mnemonic (_("Highlighter Opt_ions"));
  gtk_widget_show (toolsHighlighterOptions);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsHighlighterOptions);

  toolsHighlighterOptions_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (toolsHighlighterOptions), toolsHighlighterOptions_menu);

  highlighterFine = gtk_radio_menu_item_new_with_mnemonic (highlighterFine_group, _("_fine"));
  highlighterFine_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (highlighterFine));
  gtk_widget_show (highlighterFine);
  gtk_container_add (GTK_CONTAINER (toolsHighlighterOptions_menu), highlighterFine);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (highlighterFine), TRUE);

  highlighterMedium = gtk_radio_menu_item_new_with_mnemonic (highlighterFine_group, _("_medium"));
  highlighterFine_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (highlighterMedium));
  gtk_widget_show (highlighterMedium);
  gtk_container_add (GTK_CONTAINER (toolsHighlighterOptions_menu), highlighterMedium);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (highlighterMedium), TRUE);

  highlighterThick = gtk_radio_menu_item_new_with_mnemonic (highlighterFine_group, _("_thick"));
  highlighterFine_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (highlighterThick));
  gtk_widget_show (highlighterThick);
  gtk_container_add (GTK_CONTAINER (toolsHighlighterOptions_menu), highlighterThick);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (highlighterThick), TRUE);

  toolsTextFont = gtk_image_menu_item_new_with_mnemonic (_("Text _Font..."));
  gtk_widget_show (toolsTextFont);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsTextFont);
  gtk_widget_add_accelerator (toolsTextFont, "activate", accel_group,
                              GDK_F, (GdkModifierType) GDK_CONTROL_MASK | GDK_SHIFT_MASK,
                              GTK_ACCEL_VISIBLE);

  image634 = gtk_image_new_from_stock ("gtk-select-font", GTK_ICON_SIZE_MENU);
  gtk_widget_show (image634);
  gtk_image_menu_item_set_image (GTK_IMAGE_MENU_ITEM (toolsTextFont), image634);

  separator10 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator10);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), separator10);
  gtk_widget_set_sensitive (separator10, FALSE);

  toolsDefaultPen = gtk_menu_item_new_with_mnemonic (_("_Default Pen"));
  gtk_widget_show (toolsDefaultPen);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsDefaultPen);

  toolsDefaultEraser = gtk_menu_item_new_with_mnemonic (_("Default Eraser"));
  gtk_widget_show (toolsDefaultEraser);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsDefaultEraser);

  toolsDefaultHighlighter = gtk_menu_item_new_with_mnemonic (_("Default Highlighter"));
  gtk_widget_show (toolsDefaultHighlighter);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsDefaultHighlighter);

  toolsDefaultText = gtk_menu_item_new_with_mnemonic (_("Default Te_xt"));
  gtk_widget_show (toolsDefaultText);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsDefaultText);

  toolsSetAsDefault = gtk_menu_item_new_with_mnemonic (_("Set As Default"));
  gtk_widget_show (toolsSetAsDefault);
  gtk_container_add (GTK_CONTAINER (menuTools_menu), toolsSetAsDefault);

  menuOptions = gtk_menu_item_new_with_mnemonic (_("_Options"));
  gtk_widget_show (menuOptions);
  gtk_container_add (GTK_CONTAINER (menubar), menuOptions);

  menuOptions_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuOptions), menuOptions_menu);

  optionsUseXInput = gtk_check_menu_item_new_with_mnemonic (_("Use _XInput"));
  gtk_widget_show (optionsUseXInput);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), optionsUseXInput);

  pen_and_touch = gtk_menu_item_new_with_mnemonic (_("_Pen and Touch"));
  gtk_widget_show (pen_and_touch);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), pen_and_touch);

  pen_and_touch_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (pen_and_touch), pen_and_touch_menu);

  optionsButtonMappings = gtk_check_menu_item_new_with_mnemonic (_("_Eraser Tip"));
  gtk_widget_show (optionsButtonMappings);
  gtk_container_add (GTK_CONTAINER (pen_and_touch_menu), optionsButtonMappings);

  optionsPressureSensitive = gtk_check_menu_item_new_with_mnemonic (_("_Pressure sensitivity"));
  gtk_widget_show (optionsPressureSensitive);
  gtk_container_add (GTK_CONTAINER (pen_and_touch_menu), optionsPressureSensitive);

  optionsButtonSwitchMapping = gtk_check_menu_item_new_with_mnemonic (_("Buttons Switch Mappings"));
  gtk_widget_show (optionsButtonSwitchMapping);
  gtk_container_add (GTK_CONTAINER (pen_and_touch_menu), optionsButtonSwitchMapping);

  optionsTouchAsHandTool = gtk_check_menu_item_new_with_mnemonic (_("_Touchscreen as Hand Tool"));
  gtk_widget_show (optionsTouchAsHandTool);
  gtk_container_add (GTK_CONTAINER (pen_and_touch_menu), optionsTouchAsHandTool);

  optionsPenDisablesTouch = gtk_check_menu_item_new_with_mnemonic (_("Pen disables Touch"));
  gtk_widget_show (optionsPenDisablesTouch);
  gtk_container_add (GTK_CONTAINER (pen_and_touch_menu), optionsPenDisablesTouch);

  optionsDesignateTouchscreen = gtk_menu_item_new_with_mnemonic (_("Designate as Touchscreen..."));
  gtk_widget_show (optionsDesignateTouchscreen);
  gtk_container_add (GTK_CONTAINER (pen_and_touch_menu), optionsDesignateTouchscreen);

  button2_mapping = gtk_menu_item_new_with_mnemonic (_("Button _2 Mapping"));
  gtk_widget_show (button2_mapping);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), button2_mapping);

  button2_mapping_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (button2_mapping), button2_mapping_menu);

  button2Pen = gtk_radio_menu_item_new_with_mnemonic (button2Pen_group, _("_Pen"));
  button2Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button2Pen));
  gtk_widget_show (button2Pen);
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), button2Pen);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button2Pen), TRUE);

  button2Eraser = gtk_radio_menu_item_new_with_mnemonic (button2Pen_group, _("_Eraser"));
  button2Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button2Eraser));
  gtk_widget_show (button2Eraser);
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), button2Eraser);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button2Eraser), TRUE);

  button2Highlighter = gtk_radio_menu_item_new_with_mnemonic (button2Pen_group, _("_Highlighter"));
  button2Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button2Highlighter));
  gtk_widget_show (button2Highlighter);
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), button2Highlighter);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button2Highlighter), TRUE);

  button2Text = gtk_radio_menu_item_new_with_mnemonic (button2Pen_group, _("_Text"));
  button2Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button2Text));
  gtk_widget_show (button2Text);
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), button2Text);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button2Text), TRUE);

  button2Image = gtk_radio_menu_item_new_with_mnemonic (button2Pen_group, _("_Image"));
  button2Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button2Image));
  gtk_widget_show (button2Image);
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), button2Image);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button2Image), TRUE);

  button2SelectRegion = gtk_radio_menu_item_new_with_mnemonic (button2Pen_group, _("Select Re_gion"));
  button2Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button2SelectRegion));
  gtk_widget_show (button2SelectRegion);
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), button2SelectRegion);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button2SelectRegion), TRUE);

  button2SelectRectangle = gtk_radio_menu_item_new_with_mnemonic (button2Pen_group, _("Select _Rectangle"));
  button2Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button2SelectRectangle));
  gtk_widget_show (button2SelectRectangle);
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), button2SelectRectangle);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button2SelectRectangle), TRUE);

  button2VerticalSpace = gtk_radio_menu_item_new_with_mnemonic (button2Pen_group, _("_Vertical Space"));
  button2Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button2VerticalSpace));
  gtk_widget_show (button2VerticalSpace);
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), button2VerticalSpace);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button2VerticalSpace), TRUE);

  button2Hand = gtk_radio_menu_item_new_with_mnemonic (button2Pen_group, _("H_and Tool"));
  button2Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button2Hand));
  gtk_widget_show (button2Hand);
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), button2Hand);

  separator24 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator24);
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), separator24);
  gtk_widget_set_sensitive (separator24, FALSE);

  button2LinkBrush = gtk_radio_menu_item_new_with_mnemonic (button2LinkBrush_group, _("_Link to Primary Brush"));
  button2LinkBrush_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button2LinkBrush));
  gtk_widget_show (button2LinkBrush);
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), button2LinkBrush);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button2LinkBrush), TRUE);

  button2CopyBrush = gtk_radio_menu_item_new_with_mnemonic (button2LinkBrush_group, _("_Copy of Current Brush"));
  button2LinkBrush_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button2CopyBrush));
  gtk_widget_show (button2CopyBrush);
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), button2CopyBrush);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button2CopyBrush), TRUE);

  button2NABrush = gtk_radio_menu_item_new_with_mnemonic (button2LinkBrush_group, _("NA"));
  button2LinkBrush_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button2NABrush));
  gtk_container_add (GTK_CONTAINER (button2_mapping_menu), button2NABrush);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button2NABrush), TRUE);

  button3_mapping = gtk_menu_item_new_with_mnemonic (_("Button _3 Mapping"));
  gtk_widget_show (button3_mapping);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), button3_mapping);

  button3_mapping_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (button3_mapping), button3_mapping_menu);

  button3Pen = gtk_radio_menu_item_new_with_mnemonic (button3Pen_group, _("_Pen"));
  button3Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button3Pen));
  gtk_widget_show (button3Pen);
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), button3Pen);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button3Pen), TRUE);

  button3Eraser = gtk_radio_menu_item_new_with_mnemonic (button3Pen_group, _("_Eraser"));
  button3Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button3Eraser));
  gtk_widget_show (button3Eraser);
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), button3Eraser);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button3Eraser), TRUE);

  button3Highlighter = gtk_radio_menu_item_new_with_mnemonic (button3Pen_group, _("_Highlighter"));
  button3Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button3Highlighter));
  gtk_widget_show (button3Highlighter);
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), button3Highlighter);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button3Highlighter), TRUE);

  button3Text = gtk_radio_menu_item_new_with_mnemonic (button3Pen_group, _("_Text"));
  button3Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button3Text));
  gtk_widget_show (button3Text);
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), button3Text);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button3Text), TRUE);

  button3Image = gtk_radio_menu_item_new_with_mnemonic (button3Pen_group, _("_Image"));
  button3Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button3Image));
  gtk_widget_show (button3Image);
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), button3Image);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button3Image), TRUE);

  button3SelectRegion = gtk_radio_menu_item_new_with_mnemonic (button3Pen_group, _("Select Re_gion"));
  button3Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button3SelectRegion));
  gtk_widget_show (button3SelectRegion);
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), button3SelectRegion);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button3SelectRegion), TRUE);

  button3SelectRectangle = gtk_radio_menu_item_new_with_mnemonic (button3Pen_group, _("Select _Rectangle"));
  button3Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button3SelectRectangle));
  gtk_widget_show (button3SelectRectangle);
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), button3SelectRectangle);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button3SelectRectangle), TRUE);

  button3VerticalSpace = gtk_radio_menu_item_new_with_mnemonic (button3Pen_group, _("_Vertical Space"));
  button3Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button3VerticalSpace));
  gtk_widget_show (button3VerticalSpace);
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), button3VerticalSpace);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button3VerticalSpace), TRUE);

  button3Hand = gtk_radio_menu_item_new_with_mnemonic (button3Pen_group, _("H_and Tool"));
  button3Pen_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button3Hand));
  gtk_widget_show (button3Hand);
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), button3Hand);

  separator25 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator25);
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), separator25);
  gtk_widget_set_sensitive (separator25, FALSE);

  button3LinkBrush = gtk_radio_menu_item_new_with_mnemonic (button3LinkBrush_group, _("_Link to Primary Brush"));
  button3LinkBrush_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button3LinkBrush));
  gtk_widget_show (button3LinkBrush);
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), button3LinkBrush);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button3LinkBrush), TRUE);

  button3CopyBrush = gtk_radio_menu_item_new_with_mnemonic (button3LinkBrush_group, _("_Copy of Current Brush"));
  button3LinkBrush_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button3CopyBrush));
  gtk_widget_show (button3CopyBrush);
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), button3CopyBrush);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button3CopyBrush), TRUE);

  button3NABrush = gtk_radio_menu_item_new_with_mnemonic (button3LinkBrush_group, _("NA"));
  button3LinkBrush_group = gtk_radio_menu_item_get_group (GTK_RADIO_MENU_ITEM (button3NABrush));
  gtk_container_add (GTK_CONTAINER (button3_mapping_menu), button3NABrush);
  gtk_check_menu_item_set_active (GTK_CHECK_MENU_ITEM (button3NABrush), TRUE);

  separator18 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator18);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), separator18);
  gtk_widget_set_sensitive (separator18, FALSE);

  optionsProgressiveBG = gtk_check_menu_item_new_with_mnemonic (_("Progressive _Backgrounds"));
  gtk_widget_show (optionsProgressiveBG);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), optionsProgressiveBG);

  optionsPrintRuling = gtk_check_menu_item_new_with_mnemonic (_("Print Paper _Ruling"));
  gtk_widget_show (optionsPrintRuling);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), optionsPrintRuling);

  optionsLegacyPDFExport = gtk_check_menu_item_new_with_mnemonic (_("Legacy PDF Export"));
  gtk_widget_show (optionsLegacyPDFExport);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), optionsLegacyPDFExport);

  optionsLayersPDFExport = gtk_check_menu_item_new_with_mnemonic (_("Layers in PDF Export"));
  gtk_widget_show (optionsLayersPDFExport);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), optionsLayersPDFExport);

  optionsAutoloadPdfXoj = gtk_check_menu_item_new_with_mnemonic (_("Autoload pdf.xoj"));
  gtk_widget_show (optionsAutoloadPdfXoj);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), optionsAutoloadPdfXoj);

  optionsAutosaveXoj = gtk_check_menu_item_new_with_mnemonic (_("Auto-Save Files"));
  gtk_widget_show (optionsAutosaveXoj);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), optionsAutosaveXoj);

  optionsLeftHanded = gtk_check_menu_item_new_with_mnemonic (_("Left-Handed Scrollbar"));
  gtk_widget_show (optionsLeftHanded);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), optionsLeftHanded);

  optionsShortenMenus = gtk_check_menu_item_new_with_mnemonic (_("Shorten _Menus"));
  gtk_widget_show (optionsShortenMenus);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), optionsShortenMenus);

  optionsPenCursor = gtk_check_menu_item_new_with_mnemonic (_("Pencil Cursor"));
  gtk_widget_show (optionsPenCursor);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), optionsPenCursor);

  separator21 = gtk_separator_menu_item_new ();
  gtk_widget_show (separator21);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), separator21);
  gtk_widget_set_sensitive (separator21, FALSE);

  optionsAutoSavePrefs = gtk_check_menu_item_new_with_mnemonic (_("A_uto-Save Preferences"));
  gtk_widget_show (optionsAutoSavePrefs);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), optionsAutoSavePrefs);

  optionsSavePreferences = gtk_menu_item_new_with_mnemonic (_("_Save Preferences"));
  gtk_widget_show (optionsSavePreferences);
  gtk_container_add (GTK_CONTAINER (menuOptions_menu), optionsSavePreferences);

  menuHelp = gtk_menu_item_new_with_mnemonic (_("_Help"));
  gtk_widget_show (menuHelp);
  gtk_container_add (GTK_CONTAINER (menubar), menuHelp);

  menuHelp_menu = gtk_menu_new ();
  gtk_menu_item_set_submenu (GTK_MENU_ITEM (menuHelp), menuHelp_menu);

  helpIndex = gtk_image_menu_item_new_from_stock ("gtk-index", accel_group);
  gtk_widget_show (helpIndex);
  gtk_container_add (GTK_CONTAINER (menuHelp_menu), helpIndex);

  helpAbout = gtk_menu_item_new_with_mnemonic (_("_About"));
  gtk_widget_show (helpAbout);
  gtk_container_add (GTK_CONTAINER (menuHelp_menu), helpAbout);

  toolbarMain = gtk_toolbar_new ();
  gtk_widget_show (toolbarMain);
  gtk_box_pack_start (GTK_BOX (vboxMain), toolbarMain, FALSE, FALSE, 0);
  gtk_toolbar_set_style (GTK_TOOLBAR (toolbarMain), GTK_TOOLBAR_ICONS);
  tmp_toolbar_icon_size = gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbarMain));

  saveButton = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-save");
  gtk_widget_show (saveButton);
  gtk_container_add (GTK_CONTAINER (toolbarMain), saveButton);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (saveButton), tooltips, _("Save"), NULL);

  newButton = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-new");
  gtk_widget_show (newButton);
  gtk_container_add (GTK_CONTAINER (toolbarMain), newButton);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (newButton), tooltips, _("New"), NULL);

  openButton = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-open");
  gtk_widget_show (openButton);
  gtk_container_add (GTK_CONTAINER (toolbarMain), openButton);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (openButton), tooltips, _("Open"), NULL);

  toolitem11 = (GtkWidget*) gtk_tool_item_new ();
  gtk_widget_show (toolitem11);
  gtk_container_add (GTK_CONTAINER (toolbarMain), toolitem11);

  vseparator1 = gtk_vseparator_new ();
  gtk_widget_show (vseparator1);
  gtk_container_add (GTK_CONTAINER (toolitem11), vseparator1);

  buttonCut = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-cut");
  gtk_widget_show (buttonCut);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonCut);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonCut), tooltips, _("Cut"), NULL);

  buttonCopy = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-copy");
  gtk_widget_show (buttonCopy);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonCopy);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonCopy), tooltips, _("Copy"), NULL);

  buttonPaste = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-paste");
  gtk_widget_show (buttonPaste);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonPaste);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonPaste), tooltips, _("Paste"), NULL);

  toolitem12 = (GtkWidget*) gtk_tool_item_new ();
  gtk_widget_show (toolitem12);
  gtk_container_add (GTK_CONTAINER (toolbarMain), toolitem12);

  vseparator2 = gtk_vseparator_new ();
  gtk_widget_show (vseparator2);
  gtk_container_add (GTK_CONTAINER (toolitem12), vseparator2);

  buttonUndo = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-undo");
  gtk_widget_show (buttonUndo);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonUndo);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonUndo), tooltips, _("Undo"), NULL);

  buttonRedo = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-redo");
  gtk_widget_show (buttonRedo);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonRedo);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonRedo), tooltips, _("Redo"), NULL);

  toolitem13 = (GtkWidget*) gtk_tool_item_new ();
  gtk_widget_show (toolitem13);
  gtk_container_add (GTK_CONTAINER (toolbarMain), toolitem13);

  vseparator3 = gtk_vseparator_new ();
  gtk_widget_show (vseparator3);
  gtk_container_add (GTK_CONTAINER (toolitem13), vseparator3);

  buttonFirstPage = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-goto-first");
  gtk_widget_show (buttonFirstPage);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonFirstPage);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonFirstPage), tooltips, _("First Page"), NULL);

  buttonPreviousPage = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-go-back");
  gtk_widget_show (buttonPreviousPage);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonPreviousPage);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonPreviousPage), tooltips, _("Previous Page"), NULL);

  buttonNextPage = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-go-forward");
  gtk_widget_show (buttonNextPage);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonNextPage);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonNextPage), tooltips, _("Next Page"), NULL);

  buttonLastPage = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-goto-last");
  gtk_widget_show (buttonLastPage);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonLastPage);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonLastPage), tooltips, _("Last Page"), NULL);

  toolitem14 = (GtkWidget*) gtk_tool_item_new ();
  gtk_widget_show (toolitem14);
  gtk_container_add (GTK_CONTAINER (toolbarMain), toolitem14);

  vseparator4 = gtk_vseparator_new ();
  gtk_widget_show (vseparator4);
  gtk_container_add (GTK_CONTAINER (toolitem14), vseparator4);

  buttonZoomOut = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-zoom-out");
  gtk_widget_show (buttonZoomOut);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonZoomOut);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonZoomOut), tooltips, _("Zoom Out"), NULL);

  buttonPageWidth = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-zoom-fit");
  gtk_widget_show (buttonPageWidth);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonPageWidth);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonPageWidth), tooltips, _("Page Width"), NULL);
  gtk_tool_item_set_visible_vertical (GTK_TOOL_ITEM (buttonPageWidth), FALSE);

  buttonZoomIn = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-zoom-in");
  gtk_widget_show (buttonZoomIn);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonZoomIn);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonZoomIn), tooltips, _("Zoom In"), NULL);

  buttonNormalSize = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-zoom-100");
  gtk_widget_show (buttonNormalSize);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonNormalSize);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonNormalSize), tooltips, _("Normal Size"), NULL);

  buttonZoomSet = (GtkWidget*) gtk_tool_button_new_from_stock ("gtk-find");
  gtk_widget_show (buttonZoomSet);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonZoomSet);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonZoomSet), tooltips, _("Set Zoom"), NULL);

  buttonFullscreen = (GtkWidget*) gtk_toggle_tool_button_new ();
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonFullscreen), "");
  tmp_image = create_pixmap (winMain, "fullscreen.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonFullscreen), tmp_image);
  gtk_widget_show (buttonFullscreen);
  gtk_container_add (GTK_CONTAINER (toolbarMain), buttonFullscreen);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonFullscreen), tooltips, _("Toggle Fullscreen"), NULL);

  toolbarPen = gtk_toolbar_new ();
  gtk_widget_show (toolbarPen);
  gtk_box_pack_start (GTK_BOX (vboxMain), toolbarPen, FALSE, FALSE, 0);
  gtk_toolbar_set_style (GTK_TOOLBAR (toolbarPen), GTK_TOOLBAR_ICONS);
  tmp_toolbar_icon_size = gtk_toolbar_get_icon_size (GTK_TOOLBAR (toolbarPen));

  buttonPen = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonPen), _("Pencil"));
  tmp_image = create_pixmap (winMain, "pencil.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonPen), tmp_image);
  gtk_widget_show (buttonPen);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonPen);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonPen), tooltips, _("Pen"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonPen), buttonPen_group);
  buttonPen_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonPen));

  buttonEraser = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonEraser), _("Eraser"));
  tmp_image = create_pixmap (winMain, "eraser.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonEraser), tmp_image);
  gtk_widget_show (buttonEraser);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonEraser);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonEraser), tooltips, _("Eraser"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonEraser), buttonPen_group);
  buttonPen_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonEraser));

  buttonHighlighter = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonHighlighter), _("Highlighter"));
  tmp_image = create_pixmap (winMain, "highlighter.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonHighlighter), tmp_image);
  gtk_widget_show (buttonHighlighter);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonHighlighter);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonHighlighter), tooltips, _("Highlighter"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonHighlighter), buttonPen_group);
  buttonPen_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonHighlighter));

  buttonText = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonText), _("Text"));
  tmp_image = create_pixmap (winMain, "text-tool.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonText), tmp_image);
  gtk_widget_show (buttonText);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonText);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonText), tooltips, _("Text"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonText), buttonPen_group);
  buttonPen_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonText));

  buttonImage = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonImage), _("Image"));
  tmp_image = gtk_image_new_from_stock ("gtk-orientation-portrait", tmp_toolbar_icon_size);
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonImage), tmp_image);
  gtk_widget_show (buttonImage);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonImage);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonImage), tooltips, _("Image"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonImage), buttonPen_group);
  buttonPen_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonImage));

  buttonReco = (GtkWidget*) gtk_toggle_tool_button_new ();
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonReco), _("Shape Recognizer"));
  tmp_image = create_pixmap (winMain, "shapes.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonReco), tmp_image);
  gtk_widget_show (buttonReco);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonReco);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonReco), tooltips, _("Shape Recognizer"), NULL);

  buttonRuler = (GtkWidget*) gtk_toggle_tool_button_new ();
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonRuler), _("Ruler"));
  tmp_image = create_pixmap (winMain, "ruler.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonRuler), tmp_image);
  gtk_widget_show (buttonRuler);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonRuler);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonRuler), tooltips, _("Ruler"), NULL);

  toolitem15 = (GtkWidget*) gtk_tool_item_new ();
  gtk_widget_show (toolitem15);
  gtk_container_add (GTK_CONTAINER (toolbarPen), toolitem15);

  vseparator5 = gtk_vseparator_new ();
  gtk_widget_show (vseparator5);
  gtk_container_add (GTK_CONTAINER (toolitem15), vseparator5);

  buttonSelectRegion = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonSelectRegion), _("Select Region"));
  tmp_image = create_pixmap (winMain, "lasso.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonSelectRegion), tmp_image);
  gtk_widget_show (buttonSelectRegion);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonSelectRegion);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonSelectRegion), tooltips, _("Select Region"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonSelectRegion), buttonPen_group);
  buttonPen_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonSelectRegion));

  buttonSelectRectangle = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonSelectRectangle), _("Select Rectangle"));
  tmp_image = create_pixmap (winMain, "rect-select.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonSelectRectangle), tmp_image);
  gtk_widget_show (buttonSelectRectangle);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonSelectRectangle);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonSelectRectangle), tooltips, _("Select Rectangle"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonSelectRectangle), buttonPen_group);
  buttonPen_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonSelectRectangle));

  buttonVerticalSpace = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonVerticalSpace), _("Vertical Space"));
  tmp_image = create_pixmap (winMain, "stretch.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonVerticalSpace), tmp_image);
  gtk_widget_show (buttonVerticalSpace);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonVerticalSpace);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonVerticalSpace), tooltips, _("Vertical Space"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonVerticalSpace), buttonPen_group);
  buttonPen_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonVerticalSpace));

  buttonHand = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonHand), _("Hand Tool"));
  tmp_image = create_pixmap (winMain, "hand.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonHand), tmp_image);
  gtk_widget_show (buttonHand);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonHand);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonHand), buttonPen_group);
  buttonPen_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonHand));

  toolitem16 = (GtkWidget*) gtk_tool_item_new ();
  gtk_widget_show (toolitem16);
  gtk_container_add (GTK_CONTAINER (toolbarPen), toolitem16);

  vseparator6 = gtk_vseparator_new ();
  gtk_widget_show (vseparator6);
  gtk_container_add (GTK_CONTAINER (toolitem16), vseparator6);

  tmp_image = create_pixmap (winMain, "recycled.png");
  gtk_widget_show (tmp_image);
  buttonToolDefault = (GtkWidget*) gtk_tool_button_new (tmp_image, _("Default"));
  gtk_widget_show (buttonToolDefault);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonToolDefault), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonToolDefault);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonToolDefault), tooltips, _("Default"), NULL);

  tmp_image = create_pixmap (winMain, "default-pen.png");
  gtk_widget_show (tmp_image);
  buttonDefaultPen = (GtkWidget*) gtk_tool_button_new (tmp_image, _("Default Pen"));
  gtk_widget_show (buttonDefaultPen);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonDefaultPen);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonDefaultPen), tooltips, _("Default Pen"), NULL);

  toolitem18 = (GtkWidget*) gtk_tool_item_new ();
  gtk_widget_show (toolitem18);
  gtk_container_add (GTK_CONTAINER (toolbarPen), toolitem18);

  vseparator8 = gtk_vseparator_new ();
  gtk_widget_show (vseparator8);
  gtk_container_add (GTK_CONTAINER (toolitem18), vseparator8);

  buttonFine = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonFine), _("Fine"));
  tmp_image = create_pixmap (winMain, "thin.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonFine), tmp_image);
  gtk_widget_show (buttonFine);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonFine), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonFine);
  gtk_widget_set_size_request (buttonFine, 24, -1);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonFine), tooltips, _("Fine"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonFine), buttonFine_group);
  buttonFine_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonFine));

  buttonMedium = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonMedium), _("Medium"));
  tmp_image = create_pixmap (winMain, "medium.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonMedium), tmp_image);
  gtk_widget_show (buttonMedium);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonMedium), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonMedium);
  gtk_widget_set_size_request (buttonMedium, 24, -1);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonMedium), tooltips, _("Medium"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonMedium), buttonFine_group);
  buttonFine_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonMedium));

  buttonThick = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonThick), _("Thick"));
  tmp_image = create_pixmap (winMain, "thick.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonThick), tmp_image);
  gtk_widget_show (buttonThick);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonThick), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonThick);
  gtk_widget_set_size_request (buttonThick, 24, -1);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonThick), tooltips, _("Thick"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonThick), buttonFine_group);
  buttonFine_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonThick));

  buttonThicknessOther = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonThicknessOther), "");
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonThicknessOther);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonThicknessOther), buttonFine_group);
  buttonFine_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonThicknessOther));

  toolitem17 = (GtkWidget*) gtk_tool_item_new ();
  gtk_widget_show (toolitem17);
  gtk_container_add (GTK_CONTAINER (toolbarPen), toolitem17);

  vseparator7 = gtk_vseparator_new ();
  gtk_widget_show (vseparator7);
  gtk_container_add (GTK_CONTAINER (toolitem17), vseparator7);

  buttonBlack = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonBlack), _("Black"));
  tmp_image = create_pixmap (winMain, "black.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonBlack), tmp_image);
  gtk_widget_show (buttonBlack);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonBlack), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonBlack);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonBlack), tooltips, _("Black"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonBlack), buttonBlack_group);
  buttonBlack_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonBlack));

  buttonBlue = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonBlue), _("Blue"));
  tmp_image = create_pixmap (winMain, "blue.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonBlue), tmp_image);
  gtk_widget_show (buttonBlue);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonBlue), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonBlue);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonBlue), tooltips, _("Blue"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonBlue), buttonBlack_group);
  buttonBlack_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonBlue));

  buttonRed = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonRed), _("Red"));
  tmp_image = create_pixmap (winMain, "red.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonRed), tmp_image);
  gtk_widget_show (buttonRed);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonRed), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonRed);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonRed), tooltips, _("Red"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonRed), buttonBlack_group);
  buttonBlack_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonRed));

  buttonGreen = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonGreen), _("Green"));
  tmp_image = create_pixmap (winMain, "green.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonGreen), tmp_image);
  gtk_widget_show (buttonGreen);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonGreen), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonGreen);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonGreen), tooltips, _("Green"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonGreen), buttonBlack_group);
  buttonBlack_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonGreen));

  buttonGray = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonGray), _("Gray"));
  tmp_image = create_pixmap (winMain, "gray.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonGray), tmp_image);
  gtk_widget_show (buttonGray);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonGray), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonGray);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonGray), tooltips, _("Gray"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonGray), buttonBlack_group);
  buttonBlack_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonGray));

  buttonLightBlue = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonLightBlue), _("Light Blue"));
  tmp_image = create_pixmap (winMain, "lightblue.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonLightBlue), tmp_image);
  gtk_widget_show (buttonLightBlue);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonLightBlue), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonLightBlue);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonLightBlue), tooltips, _("Light Blue"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonLightBlue), buttonBlack_group);
  buttonBlack_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonLightBlue));

  buttonLightGreen = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonLightGreen), _("Light Green"));
  tmp_image = create_pixmap (winMain, "lightgreen.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonLightGreen), tmp_image);
  gtk_widget_show (buttonLightGreen);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonLightGreen), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonLightGreen);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonLightGreen), tooltips, _("Light Green"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonLightGreen), buttonBlack_group);
  buttonBlack_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonLightGreen));

  buttonMagenta = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonMagenta), _("Magenta"));
  tmp_image = create_pixmap (winMain, "magenta.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonMagenta), tmp_image);
  gtk_widget_show (buttonMagenta);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonMagenta), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonMagenta);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonMagenta), tooltips, _("Magenta"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonMagenta), buttonBlack_group);
  buttonBlack_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonMagenta));

  buttonOrange = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonOrange), _("Orange"));
  tmp_image = create_pixmap (winMain, "orange.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonOrange), tmp_image);
  gtk_widget_show (buttonOrange);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonOrange), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonOrange);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonOrange), tooltips, _("Orange"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonOrange), buttonBlack_group);
  buttonBlack_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonOrange));

  buttonYellow = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonYellow), _("Yellow"));
  tmp_image = create_pixmap (winMain, "yellow.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonYellow), tmp_image);
  gtk_widget_show (buttonYellow);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonYellow), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonYellow);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonYellow), tooltips, _("Yellow"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonYellow), buttonBlack_group);
  buttonBlack_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonYellow));

  buttonWhite = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonWhite), _("White"));
  tmp_image = create_pixmap (winMain, "white.png");
  gtk_widget_show (tmp_image);
  gtk_tool_button_set_icon_widget (GTK_TOOL_BUTTON (buttonWhite), tmp_image);
  gtk_widget_show (buttonWhite);
  gtk_tool_item_set_homogeneous (GTK_TOOL_ITEM (buttonWhite), FALSE);
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonWhite);
  gtk_tool_item_set_tooltip (GTK_TOOL_ITEM (buttonWhite), tooltips, _("White"), NULL);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonWhite), buttonBlack_group);
  buttonBlack_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonWhite));

  buttonColorOther = (GtkWidget*) gtk_radio_tool_button_new (NULL);
  gtk_tool_button_set_label (GTK_TOOL_BUTTON (buttonColorOther), "");
  gtk_container_add (GTK_CONTAINER (toolbarPen), buttonColorOther);
  gtk_radio_tool_button_set_group (GTK_RADIO_TOOL_BUTTON (buttonColorOther), buttonBlack_group);
  buttonBlack_group = gtk_radio_tool_button_get_group (GTK_RADIO_TOOL_BUTTON (buttonColorOther));

  toolitem22 = (GtkWidget*) gtk_tool_item_new ();
  gtk_widget_show (toolitem22);
  gtk_container_add (GTK_CONTAINER (toolbarPen), toolitem22);

  buttonColorChooser = gtk_color_button_new ();
  gtk_widget_show (buttonColorChooser);
  gtk_container_add (GTK_CONTAINER (toolitem22), buttonColorChooser);
  gtk_widget_set_size_request (buttonColorChooser, 34, 32);
  gtk_container_set_border_width (GTK_CONTAINER (buttonColorChooser), 2);
  GTK_WIDGET_UNSET_FLAGS (buttonColorChooser, GTK_CAN_FOCUS);

  toolitem21 = (GtkWidget*) gtk_tool_item_new ();
  gtk_widget_show (toolitem21);
  gtk_container_add (GTK_CONTAINER (toolbarPen), toolitem21);

  vseparator10 = gtk_vseparator_new ();
  gtk_widget_show (vseparator10);
  gtk_container_add (GTK_CONTAINER (toolitem21), vseparator10);

  toolitem20 = (GtkWidget*) gtk_tool_item_new ();
  gtk_widget_show (toolitem20);
  gtk_container_add (GTK_CONTAINER (toolbarPen), toolitem20);

  fontButton = gtk_font_button_new ();
  gtk_widget_show (fontButton);
  gtk_container_add (GTK_CONTAINER (toolitem20), fontButton);
  gtk_font_button_set_use_font (GTK_FONT_BUTTON (fontButton), TRUE);
  gtk_button_set_focus_on_click (GTK_BUTTON (fontButton), FALSE);

  scrolledwindowMain = gtk_scrolled_window_new (NULL, NULL);
  gtk_widget_show (scrolledwindowMain);
  gtk_box_pack_start (GTK_BOX (vboxMain), scrolledwindowMain, TRUE, TRUE, 0);

  hbox1 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox1);
  gtk_box_pack_start (GTK_BOX (vboxMain), hbox1, FALSE, FALSE, 0);

  labelPage = gtk_label_new (_("  Page  "));
  gtk_widget_show (labelPage);
  gtk_box_pack_start (GTK_BOX (hbox1), labelPage, FALSE, FALSE, 0);

  spinPageNo_adj = gtk_adjustment_new (1, 1, 1, 1, 0, 0);
  spinPageNo = gtk_spin_button_new (GTK_ADJUSTMENT (spinPageNo_adj), 1, 0);
  gtk_widget_show (spinPageNo);
  gtk_box_pack_start (GTK_BOX (hbox1), spinPageNo, FALSE, TRUE, 0);
  gtk_tooltips_set_tip (tooltips, spinPageNo, _("Set page number"), NULL);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinPageNo), TRUE);
  gtk_spin_button_set_snap_to_ticks (GTK_SPIN_BUTTON (spinPageNo), TRUE);

  labelNumpages = gtk_label_new (_(" of n"));
  gtk_widget_show (labelNumpages);
  gtk_box_pack_start (GTK_BOX (hbox1), labelNumpages, FALSE, FALSE, 0);

  vseparator9 = gtk_vseparator_new ();
  gtk_widget_show (vseparator9);
  gtk_box_pack_start (GTK_BOX (hbox1), vseparator9, FALSE, TRUE, 6);

  labelLayer = gtk_label_new (_("  Layer:  "));
  gtk_widget_show (labelLayer);
  gtk_box_pack_start (GTK_BOX (hbox1), labelLayer, FALSE, FALSE, 0);

  comboLayer = gtk_combo_box_new_text ();
  gtk_widget_show (comboLayer);
  gtk_box_pack_start (GTK_BOX (hbox1), comboLayer, FALSE, TRUE, 4);

  statusbar = gtk_statusbar_new ();
  gtk_widget_show (statusbar);
  gtk_box_pack_start (GTK_BOX (hbox1), statusbar, TRUE, TRUE, 0);
  gtk_statusbar_set_has_resize_grip (GTK_STATUSBAR (statusbar), FALSE);

  g_signal_connect ((gpointer) winMain, "delete_event",
                    G_CALLBACK (on_winMain_delete_event),
                    NULL);
  g_signal_connect ((gpointer) fileNew, "activate",
                    G_CALLBACK (on_fileNew_activate),
                    NULL);
  g_signal_connect ((gpointer) fileNewBackground, "activate",
                    G_CALLBACK (on_fileNewBackground_activate),
                    NULL);
  g_signal_connect ((gpointer) fileOpen, "activate",
                    G_CALLBACK (on_fileOpen_activate),
                    NULL);
  g_signal_connect ((gpointer) fileSave, "activate",
                    G_CALLBACK (on_fileSave_activate),
                    NULL);
  g_signal_connect ((gpointer) fileSaveAs, "activate",
                    G_CALLBACK (on_fileSaveAs_activate),
                    NULL);
  g_signal_connect ((gpointer) mru0, "activate",
                    G_CALLBACK (on_mru_activate),
                    NULL);
  g_signal_connect ((gpointer) mru1, "activate",
                    G_CALLBACK (on_mru_activate),
                    NULL);
  g_signal_connect ((gpointer) mru2, "activate",
                    G_CALLBACK (on_mru_activate),
                    NULL);
  g_signal_connect ((gpointer) mru3, "activate",
                    G_CALLBACK (on_mru_activate),
                    NULL);
  g_signal_connect ((gpointer) mru4, "activate",
                    G_CALLBACK (on_mru_activate),
                    NULL);
  g_signal_connect ((gpointer) mru5, "activate",
                    G_CALLBACK (on_mru_activate),
                    NULL);
  g_signal_connect ((gpointer) mru6, "activate",
                    G_CALLBACK (on_mru_activate),
                    NULL);
  g_signal_connect ((gpointer) mru7, "activate",
                    G_CALLBACK (on_mru_activate),
                    NULL);
  g_signal_connect ((gpointer) filePrintOptions, "activate",
                    G_CALLBACK (on_filePrintOptions_activate),
                    NULL);
  g_signal_connect ((gpointer) filePrint, "activate",
                    G_CALLBACK (on_filePrint_activate),
                    NULL);
  g_signal_connect ((gpointer) filePrintPDF, "activate",
                    G_CALLBACK (on_filePrintPDF_activate),
                    NULL);
  g_signal_connect ((gpointer) fileQuit, "activate",
                    G_CALLBACK (on_fileQuit_activate),
                    NULL);
  g_signal_connect ((gpointer) editUndo, "activate",
                    G_CALLBACK (on_editUndo_activate),
                    NULL);
  g_signal_connect ((gpointer) editRedo, "activate",
                    G_CALLBACK (on_editRedo_activate),
                    NULL);
  g_signal_connect ((gpointer) editCut, "activate",
                    G_CALLBACK (on_editCut_activate),
                    NULL);
  g_signal_connect ((gpointer) editCopy, "activate",
                    G_CALLBACK (on_editCopy_activate),
                    NULL);
  g_signal_connect ((gpointer) editPaste, "activate",
                    G_CALLBACK (on_editPaste_activate),
                    NULL);
  g_signal_connect ((gpointer) editDelete, "activate",
                    G_CALLBACK (on_editDelete_activate),
                    NULL);
  g_signal_connect ((gpointer) viewContinuous, "toggled",
                    G_CALLBACK (on_viewContinuous_activate),
                    NULL);
  g_signal_connect ((gpointer) viewHorizontal, "toggled",
                    G_CALLBACK (on_viewHorizontal_activate),
                    NULL);
  g_signal_connect ((gpointer) viewOnePage, "toggled",
                    G_CALLBACK (on_viewOnePage_activate),
                    NULL);
  g_signal_connect ((gpointer) viewFullscreen, "activate",
                    G_CALLBACK (on_viewFullscreen_activate),
                    NULL);
  g_signal_connect ((gpointer) viewZoomIn, "activate",
                    G_CALLBACK (on_viewZoomIn_activate),
                    NULL);
  g_signal_connect ((gpointer) viewZoomOut, "activate",
                    G_CALLBACK (on_viewZoomOut_activate),
                    NULL);
  g_signal_connect ((gpointer) viewNormalSize, "activate",
                    G_CALLBACK (on_viewNormalSize_activate),
                    NULL);
  g_signal_connect ((gpointer) viewPageWidth, "activate",
                    G_CALLBACK (on_viewPageWidth_activate),
                    NULL);
  g_signal_connect ((gpointer) viewSetZoom, "activate",
                    G_CALLBACK (on_viewSetZoom_activate),
                    NULL);
  g_signal_connect ((gpointer) viewFirstPage, "activate",
                    G_CALLBACK (on_viewFirstPage_activate),
                    NULL);
  g_signal_connect ((gpointer) viewPreviousPage, "activate",
                    G_CALLBACK (on_viewPreviousPage_activate),
                    NULL);
  g_signal_connect ((gpointer) viewNextPage, "activate",
                    G_CALLBACK (on_viewNextPage_activate),
                    NULL);
  g_signal_connect ((gpointer) viewLastPage, "activate",
                    G_CALLBACK (on_viewLastPage_activate),
                    NULL);
  g_signal_connect ((gpointer) viewShowLayer, "activate",
                    G_CALLBACK (on_viewShowLayer_activate),
                    NULL);
  g_signal_connect ((gpointer) viewHideLayer, "activate",
                    G_CALLBACK (on_viewHideLayer_activate),
                    NULL);
  g_signal_connect ((gpointer) journalNewPageBefore, "activate",
                    G_CALLBACK (on_journalNewPageBefore_activate),
                    NULL);
  g_signal_connect ((gpointer) journalNewPageAfter, "activate",
                    G_CALLBACK (on_journalNewPageAfter_activate),
                    NULL);
  g_signal_connect ((gpointer) journalNewPageEnd, "activate",
                    G_CALLBACK (on_journalNewPageEnd_activate),
                    NULL);
  g_signal_connect ((gpointer) journalNewPageKeepsBG, "activate",
                    G_CALLBACK (on_journalNewPageKeepsBG_activate),
                    NULL);
  g_signal_connect ((gpointer) journalDeletePage, "activate",
                    G_CALLBACK (on_journalDeletePage_activate),
                    NULL);
  g_signal_connect ((gpointer) journalNewLayer, "activate",
                    G_CALLBACK (on_journalNewLayer_activate),
                    NULL);
  g_signal_connect ((gpointer) journalDeleteLayer, "activate",
                    G_CALLBACK (on_journalDeleteLayer_activate),
                    NULL);
  g_signal_connect ((gpointer) journalFlatten, "activate",
                    G_CALLBACK (on_journalFlatten_activate),
                    NULL);
  g_signal_connect ((gpointer) journalPaperSize, "activate",
                    G_CALLBACK (on_journalPaperSize_activate),
                    NULL);
  g_signal_connect ((gpointer) papercolorWhite, "toggled",
                    G_CALLBACK (on_papercolorWhite_activate),
                    NULL);
  g_signal_connect ((gpointer) papercolorYellow, "toggled",
                    G_CALLBACK (on_papercolorYellow_activate),
                    NULL);
  g_signal_connect ((gpointer) papercolorPink, "toggled",
                    G_CALLBACK (on_papercolorPink_activate),
                    NULL);
  g_signal_connect ((gpointer) papercolorOrange, "toggled",
                    G_CALLBACK (on_papercolorOrange_activate),
                    NULL);
  g_signal_connect ((gpointer) papercolorBlue, "toggled",
                    G_CALLBACK (on_papercolorBlue_activate),
                    NULL);
  g_signal_connect ((gpointer) papercolorGreen, "toggled",
                    G_CALLBACK (on_papercolorGreen_activate),
                    NULL);
  g_signal_connect ((gpointer) papercolorOther, "activate",
                    G_CALLBACK (on_papercolorOther_activate),
                    NULL);
  g_signal_connect ((gpointer) paperstylePlain, "toggled",
                    G_CALLBACK (on_paperstylePlain_activate),
                    NULL);
  g_signal_connect ((gpointer) paperstyleLined, "toggled",
                    G_CALLBACK (on_paperstyleLined_activate),
                    NULL);
  g_signal_connect ((gpointer) paperstyleRuled, "toggled",
                    G_CALLBACK (on_paperstyleRuled_activate),
                    NULL);
  g_signal_connect ((gpointer) paperstyleGraph, "toggled",
                    G_CALLBACK (on_paperstyleGraph_activate),
                    NULL);
  g_signal_connect ((gpointer) journalApplyAllPages, "activate",
                    G_CALLBACK (on_journalApplyAllPages_activate),
                    NULL);
  g_signal_connect ((gpointer) journalLoadBackground, "activate",
                    G_CALLBACK (on_journalLoadBackground_activate),
                    NULL);
  g_signal_connect ((gpointer) journalScreenshot, "activate",
                    G_CALLBACK (on_journalScreenshot_activate),
                    NULL);
  g_signal_connect ((gpointer) journalDefaultBackground, "activate",
                    G_CALLBACK (on_journalDefaultBackground_activate),
                    NULL);
  g_signal_connect ((gpointer) journalSetAsDefault, "activate",
                    G_CALLBACK (on_journalSetAsDefault_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsPen, "toggled",
                    G_CALLBACK (on_toolsPen_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsEraser, "toggled",
                    G_CALLBACK (on_toolsEraser_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsHighlighter, "toggled",
                    G_CALLBACK (on_toolsHighlighter_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsText, "toggled",
                    G_CALLBACK (on_toolsText_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsImage, "toggled",
                    G_CALLBACK (on_toolsImage_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsReco, "toggled",
                    G_CALLBACK (on_toolsReco_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsRuler, "toggled",
                    G_CALLBACK (on_toolsRuler_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsSelectRegion, "toggled",
                    G_CALLBACK (on_toolsSelectRegion_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsSelectRectangle, "toggled",
                    G_CALLBACK (on_toolsSelectRectangle_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsVerticalSpace, "toggled",
                    G_CALLBACK (on_toolsVerticalSpace_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsHand, "activate",
                    G_CALLBACK (on_toolsHand_activate),
                    NULL);
  g_signal_connect ((gpointer) colorBlack, "toggled",
                    G_CALLBACK (on_colorBlack_activate),
                    NULL);
  g_signal_connect ((gpointer) colorBlue, "toggled",
                    G_CALLBACK (on_colorBlue_activate),
                    NULL);
  g_signal_connect ((gpointer) colorRed, "toggled",
                    G_CALLBACK (on_colorRed_activate),
                    NULL);
  g_signal_connect ((gpointer) colorGreen, "toggled",
                    G_CALLBACK (on_colorGreen_activate),
                    NULL);
  g_signal_connect ((gpointer) colorGray, "toggled",
                    G_CALLBACK (on_colorGray_activate),
                    NULL);
  g_signal_connect ((gpointer) colorLightBlue, "toggled",
                    G_CALLBACK (on_colorLightBlue_activate),
                    NULL);
  g_signal_connect ((gpointer) colorLightGreen, "toggled",
                    G_CALLBACK (on_colorLightGreen_activate),
                    NULL);
  g_signal_connect ((gpointer) colorMagenta, "toggled",
                    G_CALLBACK (on_colorMagenta_activate),
                    NULL);
  g_signal_connect ((gpointer) colorOrange, "toggled",
                    G_CALLBACK (on_colorOrange_activate),
                    NULL);
  g_signal_connect ((gpointer) colorYellow, "toggled",
                    G_CALLBACK (on_colorYellow_activate),
                    NULL);
  g_signal_connect ((gpointer) colorWhite, "toggled",
                    G_CALLBACK (on_colorWhite_activate),
                    NULL);
  g_signal_connect ((gpointer) colorOther, "activate",
                    G_CALLBACK (on_colorOther_activate),
                    NULL);
  g_signal_connect ((gpointer) penthicknessVeryFine, "toggled",
                    G_CALLBACK (on_penthicknessVeryFine_activate),
                    NULL);
  g_signal_connect ((gpointer) penthicknessFine, "toggled",
                    G_CALLBACK (on_penthicknessFine_activate),
                    NULL);
  g_signal_connect ((gpointer) penthicknessMedium, "toggled",
                    G_CALLBACK (on_penthicknessMedium_activate),
                    NULL);
  g_signal_connect ((gpointer) penthicknessThick, "toggled",
                    G_CALLBACK (on_penthicknessThick_activate),
                    NULL);
  g_signal_connect ((gpointer) penthicknessVeryThick, "toggled",
                    G_CALLBACK (on_penthicknessVeryThick_activate),
                    NULL);
  g_signal_connect ((gpointer) eraserFine, "toggled",
                    G_CALLBACK (on_eraserFine_activate),
                    NULL);
  g_signal_connect ((gpointer) eraserMedium, "toggled",
                    G_CALLBACK (on_eraserMedium_activate),
                    NULL);
  g_signal_connect ((gpointer) eraserThick, "toggled",
                    G_CALLBACK (on_eraserThick_activate),
                    NULL);
  g_signal_connect ((gpointer) eraserStandard, "toggled",
                    G_CALLBACK (on_eraserStandard_activate),
                    NULL);
  g_signal_connect ((gpointer) eraserWhiteout, "toggled",
                    G_CALLBACK (on_eraserWhiteout_activate),
                    NULL);
  g_signal_connect ((gpointer) eraserDeleteStrokes, "toggled",
                    G_CALLBACK (on_eraserDeleteStrokes_activate),
                    NULL);
  g_signal_connect ((gpointer) highlighterFine, "toggled",
                    G_CALLBACK (on_highlighterFine_activate),
                    NULL);
  g_signal_connect ((gpointer) highlighterMedium, "toggled",
                    G_CALLBACK (on_highlighterMedium_activate),
                    NULL);
  g_signal_connect ((gpointer) highlighterThick, "toggled",
                    G_CALLBACK (on_highlighterThick_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsTextFont, "activate",
                    G_CALLBACK (on_toolsTextFont_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsDefaultPen, "activate",
                    G_CALLBACK (on_toolsDefaultPen_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsDefaultEraser, "activate",
                    G_CALLBACK (on_toolsDefaultEraser_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsDefaultHighlighter, "activate",
                    G_CALLBACK (on_toolsDefaultHighlighter_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsDefaultText, "activate",
                    G_CALLBACK (on_toolsDefaultText_activate),
                    NULL);
  g_signal_connect ((gpointer) toolsSetAsDefault, "activate",
                    G_CALLBACK (on_toolsSetAsDefault_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsUseXInput, "toggled",
                    G_CALLBACK (on_optionsUseXInput_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsButtonMappings, "activate",
                    G_CALLBACK (on_optionsButtonMappings_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsPressureSensitive, "activate",
                    G_CALLBACK (on_optionsPressureSensitive_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsButtonSwitchMapping, "toggled",
                    G_CALLBACK (on_optionsButtonsSwitchMappings_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsTouchAsHandTool, "activate",
                    G_CALLBACK (on_optionsTouchAsHandTool_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsPenDisablesTouch, "activate",
                    G_CALLBACK (on_optionsPenDisablesTouch_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsDesignateTouchscreen, "activate",
                    G_CALLBACK (on_optionsDesignateTouchscreen_activate),
                    NULL);
  g_signal_connect ((gpointer) button2Pen, "activate",
                    G_CALLBACK (on_button2Pen_activate),
                    NULL);
  g_signal_connect ((gpointer) button2Eraser, "activate",
                    G_CALLBACK (on_button2Eraser_activate),
                    NULL);
  g_signal_connect ((gpointer) button2Highlighter, "activate",
                    G_CALLBACK (on_button2Highlighter_activate),
                    NULL);
  g_signal_connect ((gpointer) button2Text, "activate",
                    G_CALLBACK (on_button2Text_activate),
                    NULL);
  g_signal_connect ((gpointer) button2Image, "activate",
                    G_CALLBACK (on_button2Image_activate),
                    NULL);
  g_signal_connect ((gpointer) button2SelectRegion, "activate",
                    G_CALLBACK (on_button2SelectRegion_activate),
                    NULL);
  g_signal_connect ((gpointer) button2SelectRectangle, "activate",
                    G_CALLBACK (on_button2SelectRectangle_activate),
                    NULL);
  g_signal_connect ((gpointer) button2VerticalSpace, "activate",
                    G_CALLBACK (on_button2VerticalSpace_activate),
                    NULL);
  g_signal_connect ((gpointer) button2Hand, "activate",
                    G_CALLBACK (on_button2Hand_activate),
                    NULL);
  g_signal_connect ((gpointer) button2LinkBrush, "activate",
                    G_CALLBACK (on_button2LinkBrush_activate),
                    NULL);
  g_signal_connect ((gpointer) button2CopyBrush, "activate",
                    G_CALLBACK (on_button2CopyBrush_activate),
                    NULL);
  g_signal_connect ((gpointer) button3Pen, "activate",
                    G_CALLBACK (on_button3Pen_activate),
                    NULL);
  g_signal_connect ((gpointer) button3Eraser, "activate",
                    G_CALLBACK (on_button3Eraser_activate),
                    NULL);
  g_signal_connect ((gpointer) button3Highlighter, "activate",
                    G_CALLBACK (on_button3Highlighter_activate),
                    NULL);
  g_signal_connect ((gpointer) button3Text, "activate",
                    G_CALLBACK (on_button3Text_activate),
                    NULL);
  g_signal_connect ((gpointer) button3Image, "activate",
                    G_CALLBACK (on_button3Image_activate),
                    NULL);
  g_signal_connect ((gpointer) button3SelectRegion, "activate",
                    G_CALLBACK (on_button3SelectRegion_activate),
                    NULL);
  g_signal_connect ((gpointer) button3SelectRectangle, "activate",
                    G_CALLBACK (on_button3SelectRectangle_activate),
                    NULL);
  g_signal_connect ((gpointer) button3VerticalSpace, "activate",
                    G_CALLBACK (on_button3VerticalSpace_activate),
                    NULL);
  g_signal_connect ((gpointer) button3Hand, "activate",
                    G_CALLBACK (on_button3Hand_activate),
                    NULL);
  g_signal_connect ((gpointer) button3LinkBrush, "activate",
                    G_CALLBACK (on_button3LinkBrush_activate),
                    NULL);
  g_signal_connect ((gpointer) button3CopyBrush, "activate",
                    G_CALLBACK (on_button3CopyBrush_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsProgressiveBG, "activate",
                    G_CALLBACK (on_optionsProgressiveBG_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsPrintRuling, "activate",
                    G_CALLBACK (on_optionsPrintRuling_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsLegacyPDFExport, "activate",
                    G_CALLBACK (on_optionsLegacyPDFExport_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsLayersPDFExport, "activate",
                    G_CALLBACK (on_optionsLayersPDFExport_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsAutoloadPdfXoj, "activate",
                    G_CALLBACK (on_optionsAutoloadPdfXoj_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsAutosaveXoj, "activate",
                    G_CALLBACK (on_optionsAutosaveXoj_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsLeftHanded, "toggled",
                    G_CALLBACK (on_optionsLeftHanded_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsShortenMenus, "toggled",
                    G_CALLBACK (on_optionsShortenMenus_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsPenCursor, "toggled",
                    G_CALLBACK (on_optionsPenCursor_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsAutoSavePrefs, "toggled",
                    G_CALLBACK (on_optionsAutoSavePrefs_activate),
                    NULL);
  g_signal_connect ((gpointer) optionsSavePreferences, "activate",
                    G_CALLBACK (on_optionsSavePreferences_activate),
                    NULL);
  g_signal_connect ((gpointer) helpIndex, "activate",
                    G_CALLBACK (on_helpIndex_activate),
                    NULL);
  g_signal_connect ((gpointer) helpAbout, "activate",
                    G_CALLBACK (on_helpAbout_activate),
                    NULL);
  g_signal_connect ((gpointer) saveButton, "clicked",
                    G_CALLBACK (on_fileSave_activate),
                    NULL);
  g_signal_connect ((gpointer) newButton, "clicked",
                    G_CALLBACK (on_fileNew_activate),
                    NULL);
  g_signal_connect ((gpointer) openButton, "clicked",
                    G_CALLBACK (on_fileOpen_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonCut, "clicked",
                    G_CALLBACK (on_editCut_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonCopy, "clicked",
                    G_CALLBACK (on_editCopy_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonPaste, "clicked",
                    G_CALLBACK (on_editPaste_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonUndo, "clicked",
                    G_CALLBACK (on_editUndo_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonRedo, "clicked",
                    G_CALLBACK (on_editRedo_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonFirstPage, "clicked",
                    G_CALLBACK (on_viewFirstPage_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonPreviousPage, "clicked",
                    G_CALLBACK (on_viewPreviousPage_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonNextPage, "clicked",
                    G_CALLBACK (on_viewNextPage_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonLastPage, "clicked",
                    G_CALLBACK (on_viewLastPage_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonZoomOut, "clicked",
                    G_CALLBACK (on_viewZoomOut_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonPageWidth, "clicked",
                    G_CALLBACK (on_viewPageWidth_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonZoomIn, "clicked",
                    G_CALLBACK (on_viewZoomIn_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonNormalSize, "clicked",
                    G_CALLBACK (on_viewNormalSize_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonZoomSet, "clicked",
                    G_CALLBACK (on_viewSetZoom_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonFullscreen, "toggled",
                    G_CALLBACK (on_viewFullscreen_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonPen, "toggled",
                    G_CALLBACK (on_toolsPen_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonEraser, "toggled",
                    G_CALLBACK (on_toolsEraser_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonHighlighter, "toggled",
                    G_CALLBACK (on_toolsHighlighter_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonText, "toggled",
                    G_CALLBACK (on_toolsText_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonImage, "toggled",
                    G_CALLBACK (on_toolsImage_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonReco, "toggled",
                    G_CALLBACK (on_toolsReco_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonRuler, "toggled",
                    G_CALLBACK (on_toolsRuler_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonSelectRegion, "toggled",
                    G_CALLBACK (on_toolsSelectRegion_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonSelectRectangle, "toggled",
                    G_CALLBACK (on_toolsSelectRectangle_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonVerticalSpace, "toggled",
                    G_CALLBACK (on_toolsVerticalSpace_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonHand, "toggled",
                    G_CALLBACK (on_toolsHand_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonToolDefault, "clicked",
                    G_CALLBACK (on_buttonToolDefault_clicked),
                    NULL);
  g_signal_connect ((gpointer) buttonDefaultPen, "clicked",
                    G_CALLBACK (on_toolsDefaultPen_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonFine, "toggled",
                    G_CALLBACK (on_buttonFine_clicked),
                    NULL);
  g_signal_connect ((gpointer) buttonMedium, "toggled",
                    G_CALLBACK (on_buttonMedium_clicked),
                    NULL);
  g_signal_connect ((gpointer) buttonThick, "toggled",
                    G_CALLBACK (on_buttonThick_clicked),
                    NULL);
  g_signal_connect ((gpointer) buttonBlack, "toggled",
                    G_CALLBACK (on_colorBlack_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonBlue, "toggled",
                    G_CALLBACK (on_colorBlue_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonRed, "toggled",
                    G_CALLBACK (on_colorRed_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonGreen, "toggled",
                    G_CALLBACK (on_colorGreen_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonGray, "toggled",
                    G_CALLBACK (on_colorGray_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonLightBlue, "toggled",
                    G_CALLBACK (on_colorLightBlue_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonLightGreen, "toggled",
                    G_CALLBACK (on_colorLightGreen_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonMagenta, "toggled",
                    G_CALLBACK (on_colorMagenta_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonOrange, "toggled",
                    G_CALLBACK (on_colorOrange_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonYellow, "toggled",
                    G_CALLBACK (on_colorYellow_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonWhite, "toggled",
                    G_CALLBACK (on_colorWhite_activate),
                    NULL);
  g_signal_connect ((gpointer) buttonColorChooser, "color_set",
                    G_CALLBACK (on_buttonColorChooser_set),
                    NULL);
  g_signal_connect ((gpointer) fontButton, "font_set",
                    G_CALLBACK (on_fontButton_font_set),
                    NULL);
  g_signal_connect ((gpointer) spinPageNo, "value_changed",
                    G_CALLBACK (on_spinPageNo_value_changed),
                    NULL);
  g_signal_connect ((gpointer) comboLayer, "changed",
                    G_CALLBACK (on_comboLayer_changed),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (winMain, winMain, "winMain");
  GLADE_HOOKUP_OBJECT (winMain, vboxMain, "vboxMain");
  GLADE_HOOKUP_OBJECT (winMain, menubar, "menubar");
  GLADE_HOOKUP_OBJECT (winMain, menuFile, "menuFile");
  GLADE_HOOKUP_OBJECT (winMain, menuFile_menu, "menuFile_menu");
  GLADE_HOOKUP_OBJECT (winMain, fileNew, "fileNew");
  GLADE_HOOKUP_OBJECT (winMain, fileNewBackground, "fileNewBackground");
  GLADE_HOOKUP_OBJECT (winMain, image623, "image623");
  GLADE_HOOKUP_OBJECT (winMain, fileOpen, "fileOpen");
  GLADE_HOOKUP_OBJECT (winMain, fileSave, "fileSave");
  GLADE_HOOKUP_OBJECT (winMain, fileSaveAs, "fileSaveAs");
  GLADE_HOOKUP_OBJECT (winMain, separator1, "separator1");
  GLADE_HOOKUP_OBJECT (winMain, fileRecentFiles, "fileRecentFiles");
  GLADE_HOOKUP_OBJECT (winMain, fileRecentFiles_menu, "fileRecentFiles_menu");
  GLADE_HOOKUP_OBJECT (winMain, mru0, "mru0");
  GLADE_HOOKUP_OBJECT (winMain, mru1, "mru1");
  GLADE_HOOKUP_OBJECT (winMain, mru2, "mru2");
  GLADE_HOOKUP_OBJECT (winMain, mru3, "mru3");
  GLADE_HOOKUP_OBJECT (winMain, mru4, "mru4");
  GLADE_HOOKUP_OBJECT (winMain, mru5, "mru5");
  GLADE_HOOKUP_OBJECT (winMain, mru6, "mru6");
  GLADE_HOOKUP_OBJECT (winMain, mru7, "mru7");
  GLADE_HOOKUP_OBJECT (winMain, separator22, "separator22");
  GLADE_HOOKUP_OBJECT (winMain, filePrintOptions, "filePrintOptions");
  GLADE_HOOKUP_OBJECT (winMain, image624, "image624");
  GLADE_HOOKUP_OBJECT (winMain, filePrint, "filePrint");
  GLADE_HOOKUP_OBJECT (winMain, filePrintPDF, "filePrintPDF");
  GLADE_HOOKUP_OBJECT (winMain, separator2, "separator2");
  GLADE_HOOKUP_OBJECT (winMain, fileQuit, "fileQuit");
  GLADE_HOOKUP_OBJECT (winMain, menuEdit, "menuEdit");
  GLADE_HOOKUP_OBJECT (winMain, menuEdit_menu, "menuEdit_menu");
  GLADE_HOOKUP_OBJECT (winMain, editUndo, "editUndo");
  GLADE_HOOKUP_OBJECT (winMain, editRedo, "editRedo");
  GLADE_HOOKUP_OBJECT (winMain, separator3, "separator3");
  GLADE_HOOKUP_OBJECT (winMain, editCut, "editCut");
  GLADE_HOOKUP_OBJECT (winMain, editCopy, "editCopy");
  GLADE_HOOKUP_OBJECT (winMain, editPaste, "editPaste");
  GLADE_HOOKUP_OBJECT (winMain, editDelete, "editDelete");
  GLADE_HOOKUP_OBJECT (winMain, menuView, "menuView");
  GLADE_HOOKUP_OBJECT (winMain, menuView_menu, "menuView_menu");
  GLADE_HOOKUP_OBJECT (winMain, viewContinuous, "viewContinuous");
  GLADE_HOOKUP_OBJECT (winMain, viewHorizontal, "viewHorizontal");
  GLADE_HOOKUP_OBJECT (winMain, viewOnePage, "viewOnePage");
  GLADE_HOOKUP_OBJECT (winMain, separator20, "separator20");
  GLADE_HOOKUP_OBJECT (winMain, viewFullscreen, "viewFullscreen");
  GLADE_HOOKUP_OBJECT (winMain, separator4, "separator4");
  GLADE_HOOKUP_OBJECT (winMain, menuViewZoom, "menuViewZoom");
  GLADE_HOOKUP_OBJECT (winMain, menuViewZoom_menu, "menuViewZoom_menu");
  GLADE_HOOKUP_OBJECT (winMain, viewZoomIn, "viewZoomIn");
  GLADE_HOOKUP_OBJECT (winMain, viewZoomOut, "viewZoomOut");
  GLADE_HOOKUP_OBJECT (winMain, viewNormalSize, "viewNormalSize");
  GLADE_HOOKUP_OBJECT (winMain, viewPageWidth, "viewPageWidth");
  GLADE_HOOKUP_OBJECT (winMain, image625, "image625");
  GLADE_HOOKUP_OBJECT (winMain, viewSetZoom, "viewSetZoom");
  GLADE_HOOKUP_OBJECT (winMain, separator5, "separator5");
  GLADE_HOOKUP_OBJECT (winMain, viewFirstPage, "viewFirstPage");
  GLADE_HOOKUP_OBJECT (winMain, image626, "image626");
  GLADE_HOOKUP_OBJECT (winMain, viewPreviousPage, "viewPreviousPage");
  GLADE_HOOKUP_OBJECT (winMain, image627, "image627");
  GLADE_HOOKUP_OBJECT (winMain, viewNextPage, "viewNextPage");
  GLADE_HOOKUP_OBJECT (winMain, image628, "image628");
  GLADE_HOOKUP_OBJECT (winMain, viewLastPage, "viewLastPage");
  GLADE_HOOKUP_OBJECT (winMain, image629, "image629");
  GLADE_HOOKUP_OBJECT (winMain, separator6, "separator6");
  GLADE_HOOKUP_OBJECT (winMain, viewShowLayer, "viewShowLayer");
  GLADE_HOOKUP_OBJECT (winMain, image630, "image630");
  GLADE_HOOKUP_OBJECT (winMain, viewHideLayer, "viewHideLayer");
  GLADE_HOOKUP_OBJECT (winMain, image631, "image631");
  GLADE_HOOKUP_OBJECT (winMain, menuJournal, "menuJournal");
  GLADE_HOOKUP_OBJECT (winMain, menuJournal_menu, "menuJournal_menu");
  GLADE_HOOKUP_OBJECT (winMain, journalNewPageBefore, "journalNewPageBefore");
  GLADE_HOOKUP_OBJECT (winMain, journalNewPageAfter, "journalNewPageAfter");
  GLADE_HOOKUP_OBJECT (winMain, journalNewPageEnd, "journalNewPageEnd");
  GLADE_HOOKUP_OBJECT (winMain, journalNewPageKeepsBG, "journalNewPageKeepsBG");
  GLADE_HOOKUP_OBJECT (winMain, journalDeletePage, "journalDeletePage");
  GLADE_HOOKUP_OBJECT (winMain, separator7, "separator7");
  GLADE_HOOKUP_OBJECT (winMain, journalNewLayer, "journalNewLayer");
  GLADE_HOOKUP_OBJECT (winMain, journalDeleteLayer, "journalDeleteLayer");
  GLADE_HOOKUP_OBJECT (winMain, journalFlatten, "journalFlatten");
  GLADE_HOOKUP_OBJECT (winMain, separator8, "separator8");
  GLADE_HOOKUP_OBJECT (winMain, journalPaperSize, "journalPaperSize");
  GLADE_HOOKUP_OBJECT (winMain, journalPaperColor, "journalPaperColor");
  GLADE_HOOKUP_OBJECT (winMain, journalPaperColor_menu, "journalPaperColor_menu");
  GLADE_HOOKUP_OBJECT (winMain, papercolorWhite, "papercolorWhite");
  GLADE_HOOKUP_OBJECT (winMain, papercolorYellow, "papercolorYellow");
  GLADE_HOOKUP_OBJECT (winMain, papercolorPink, "papercolorPink");
  GLADE_HOOKUP_OBJECT (winMain, papercolorOrange, "papercolorOrange");
  GLADE_HOOKUP_OBJECT (winMain, papercolorBlue, "papercolorBlue");
  GLADE_HOOKUP_OBJECT (winMain, papercolorGreen, "papercolorGreen");
  GLADE_HOOKUP_OBJECT (winMain, papercolorOther, "papercolorOther");
  GLADE_HOOKUP_OBJECT (winMain, papercolorNA, "papercolorNA");
  GLADE_HOOKUP_OBJECT (winMain, journalPaperStyle, "journalPaperStyle");
  GLADE_HOOKUP_OBJECT (winMain, journalPaperStyle_menu, "journalPaperStyle_menu");
  GLADE_HOOKUP_OBJECT (winMain, paperstylePlain, "paperstylePlain");
  GLADE_HOOKUP_OBJECT (winMain, paperstyleLined, "paperstyleLined");
  GLADE_HOOKUP_OBJECT (winMain, paperstyleRuled, "paperstyleRuled");
  GLADE_HOOKUP_OBJECT (winMain, paperstyleGraph, "paperstyleGraph");
  GLADE_HOOKUP_OBJECT (winMain, paperstyleNA, "paperstyleNA");
  GLADE_HOOKUP_OBJECT (winMain, journalApplyAllPages, "journalApplyAllPages");
  GLADE_HOOKUP_OBJECT (winMain, separator23, "separator23");
  GLADE_HOOKUP_OBJECT (winMain, journalLoadBackground, "journalLoadBackground");
  GLADE_HOOKUP_OBJECT (winMain, image632, "image632");
  GLADE_HOOKUP_OBJECT (winMain, journalScreenshot, "journalScreenshot");
  GLADE_HOOKUP_OBJECT (winMain, separator19, "separator19");
  GLADE_HOOKUP_OBJECT (winMain, journalDefaultBackground, "journalDefaultBackground");
  GLADE_HOOKUP_OBJECT (winMain, journalSetAsDefault, "journalSetAsDefault");
  GLADE_HOOKUP_OBJECT (winMain, menuTools, "menuTools");
  GLADE_HOOKUP_OBJECT (winMain, menuTools_menu, "menuTools_menu");
  GLADE_HOOKUP_OBJECT (winMain, toolsPen, "toolsPen");
  GLADE_HOOKUP_OBJECT (winMain, toolsEraser, "toolsEraser");
  GLADE_HOOKUP_OBJECT (winMain, toolsHighlighter, "toolsHighlighter");
  GLADE_HOOKUP_OBJECT (winMain, toolsText, "toolsText");
  GLADE_HOOKUP_OBJECT (winMain, toolsImage, "toolsImage");
  GLADE_HOOKUP_OBJECT (winMain, separator15, "separator15");
  GLADE_HOOKUP_OBJECT (winMain, toolsReco, "toolsReco");
  GLADE_HOOKUP_OBJECT (winMain, toolsRuler, "toolsRuler");
  GLADE_HOOKUP_OBJECT (winMain, separator9, "separator9");
  GLADE_HOOKUP_OBJECT (winMain, toolsSelectRegion, "toolsSelectRegion");
  GLADE_HOOKUP_OBJECT (winMain, toolsSelectRectangle, "toolsSelectRectangle");
  GLADE_HOOKUP_OBJECT (winMain, toolsVerticalSpace, "toolsVerticalSpace");
  GLADE_HOOKUP_OBJECT (winMain, toolsHand, "toolsHand");
  GLADE_HOOKUP_OBJECT (winMain, separator16, "separator16");
  GLADE_HOOKUP_OBJECT (winMain, toolsColor, "toolsColor");
  GLADE_HOOKUP_OBJECT (winMain, image633, "image633");
  GLADE_HOOKUP_OBJECT (winMain, toolsColor_menu, "toolsColor_menu");
  GLADE_HOOKUP_OBJECT (winMain, colorBlack, "colorBlack");
  GLADE_HOOKUP_OBJECT (winMain, colorBlue, "colorBlue");
  GLADE_HOOKUP_OBJECT (winMain, colorRed, "colorRed");
  GLADE_HOOKUP_OBJECT (winMain, colorGreen, "colorGreen");
  GLADE_HOOKUP_OBJECT (winMain, colorGray, "colorGray");
  GLADE_HOOKUP_OBJECT (winMain, separator17, "separator17");
  GLADE_HOOKUP_OBJECT (winMain, colorLightBlue, "colorLightBlue");
  GLADE_HOOKUP_OBJECT (winMain, colorLightGreen, "colorLightGreen");
  GLADE_HOOKUP_OBJECT (winMain, colorMagenta, "colorMagenta");
  GLADE_HOOKUP_OBJECT (winMain, colorOrange, "colorOrange");
  GLADE_HOOKUP_OBJECT (winMain, colorYellow, "colorYellow");
  GLADE_HOOKUP_OBJECT (winMain, colorWhite, "colorWhite");
  GLADE_HOOKUP_OBJECT (winMain, colorOther, "colorOther");
  GLADE_HOOKUP_OBJECT (winMain, colorNA, "colorNA");
  GLADE_HOOKUP_OBJECT (winMain, toolsPenOptions, "toolsPenOptions");
  GLADE_HOOKUP_OBJECT (winMain, toolsPenOptions_menu, "toolsPenOptions_menu");
  GLADE_HOOKUP_OBJECT (winMain, penthicknessVeryFine, "penthicknessVeryFine");
  GLADE_HOOKUP_OBJECT (winMain, penthicknessFine, "penthicknessFine");
  GLADE_HOOKUP_OBJECT (winMain, penthicknessMedium, "penthicknessMedium");
  GLADE_HOOKUP_OBJECT (winMain, penthicknessThick, "penthicknessThick");
  GLADE_HOOKUP_OBJECT (winMain, penthicknessVeryThick, "penthicknessVeryThick");
  GLADE_HOOKUP_OBJECT (winMain, toolsEraserOptions, "toolsEraserOptions");
  GLADE_HOOKUP_OBJECT (winMain, toolsEraserOptions_menu, "toolsEraserOptions_menu");
  GLADE_HOOKUP_OBJECT (winMain, eraserFine, "eraserFine");
  GLADE_HOOKUP_OBJECT (winMain, eraserMedium, "eraserMedium");
  GLADE_HOOKUP_OBJECT (winMain, eraserThick, "eraserThick");
  GLADE_HOOKUP_OBJECT (winMain, separator14, "separator14");
  GLADE_HOOKUP_OBJECT (winMain, eraserStandard, "eraserStandard");
  GLADE_HOOKUP_OBJECT (winMain, eraserWhiteout, "eraserWhiteout");
  GLADE_HOOKUP_OBJECT (winMain, eraserDeleteStrokes, "eraserDeleteStrokes");
  GLADE_HOOKUP_OBJECT (winMain, toolsHighlighterOptions, "toolsHighlighterOptions");
  GLADE_HOOKUP_OBJECT (winMain, toolsHighlighterOptions_menu, "toolsHighlighterOptions_menu");
  GLADE_HOOKUP_OBJECT (winMain, highlighterFine, "highlighterFine");
  GLADE_HOOKUP_OBJECT (winMain, highlighterMedium, "highlighterMedium");
  GLADE_HOOKUP_OBJECT (winMain, highlighterThick, "highlighterThick");
  GLADE_HOOKUP_OBJECT (winMain, toolsTextFont, "toolsTextFont");
  GLADE_HOOKUP_OBJECT (winMain, image634, "image634");
  GLADE_HOOKUP_OBJECT (winMain, separator10, "separator10");
  GLADE_HOOKUP_OBJECT (winMain, toolsDefaultPen, "toolsDefaultPen");
  GLADE_HOOKUP_OBJECT (winMain, toolsDefaultEraser, "toolsDefaultEraser");
  GLADE_HOOKUP_OBJECT (winMain, toolsDefaultHighlighter, "toolsDefaultHighlighter");
  GLADE_HOOKUP_OBJECT (winMain, toolsDefaultText, "toolsDefaultText");
  GLADE_HOOKUP_OBJECT (winMain, toolsSetAsDefault, "toolsSetAsDefault");
  GLADE_HOOKUP_OBJECT (winMain, menuOptions, "menuOptions");
  GLADE_HOOKUP_OBJECT (winMain, menuOptions_menu, "menuOptions_menu");
  GLADE_HOOKUP_OBJECT (winMain, optionsUseXInput, "optionsUseXInput");
  GLADE_HOOKUP_OBJECT (winMain, pen_and_touch, "pen_and_touch");
  GLADE_HOOKUP_OBJECT (winMain, pen_and_touch_menu, "pen_and_touch_menu");
  GLADE_HOOKUP_OBJECT (winMain, optionsButtonMappings, "optionsButtonMappings");
  GLADE_HOOKUP_OBJECT (winMain, optionsPressureSensitive, "optionsPressureSensitive");
  GLADE_HOOKUP_OBJECT (winMain, optionsButtonSwitchMapping, "optionsButtonSwitchMapping");
  GLADE_HOOKUP_OBJECT (winMain, optionsTouchAsHandTool, "optionsTouchAsHandTool");
  GLADE_HOOKUP_OBJECT (winMain, optionsPenDisablesTouch, "optionsPenDisablesTouch");
  GLADE_HOOKUP_OBJECT (winMain, optionsDesignateTouchscreen, "optionsDesignateTouchscreen");
  GLADE_HOOKUP_OBJECT (winMain, button2_mapping, "button2_mapping");
  GLADE_HOOKUP_OBJECT (winMain, button2_mapping_menu, "button2_mapping_menu");
  GLADE_HOOKUP_OBJECT (winMain, button2Pen, "button2Pen");
  GLADE_HOOKUP_OBJECT (winMain, button2Eraser, "button2Eraser");
  GLADE_HOOKUP_OBJECT (winMain, button2Highlighter, "button2Highlighter");
  GLADE_HOOKUP_OBJECT (winMain, button2Text, "button2Text");
  GLADE_HOOKUP_OBJECT (winMain, button2Image, "button2Image");
  GLADE_HOOKUP_OBJECT (winMain, button2SelectRegion, "button2SelectRegion");
  GLADE_HOOKUP_OBJECT (winMain, button2SelectRectangle, "button2SelectRectangle");
  GLADE_HOOKUP_OBJECT (winMain, button2VerticalSpace, "button2VerticalSpace");
  GLADE_HOOKUP_OBJECT (winMain, button2Hand, "button2Hand");
  GLADE_HOOKUP_OBJECT (winMain, separator24, "separator24");
  GLADE_HOOKUP_OBJECT (winMain, button2LinkBrush, "button2LinkBrush");
  GLADE_HOOKUP_OBJECT (winMain, button2CopyBrush, "button2CopyBrush");
  GLADE_HOOKUP_OBJECT (winMain, button2NABrush, "button2NABrush");
  GLADE_HOOKUP_OBJECT (winMain, button3_mapping, "button3_mapping");
  GLADE_HOOKUP_OBJECT (winMain, button3_mapping_menu, "button3_mapping_menu");
  GLADE_HOOKUP_OBJECT (winMain, button3Pen, "button3Pen");
  GLADE_HOOKUP_OBJECT (winMain, button3Eraser, "button3Eraser");
  GLADE_HOOKUP_OBJECT (winMain, button3Highlighter, "button3Highlighter");
  GLADE_HOOKUP_OBJECT (winMain, button3Text, "button3Text");
  GLADE_HOOKUP_OBJECT (winMain, button3Image, "button3Image");
  GLADE_HOOKUP_OBJECT (winMain, button3SelectRegion, "button3SelectRegion");
  GLADE_HOOKUP_OBJECT (winMain, button3SelectRectangle, "button3SelectRectangle");
  GLADE_HOOKUP_OBJECT (winMain, button3VerticalSpace, "button3VerticalSpace");
  GLADE_HOOKUP_OBJECT (winMain, button3Hand, "button3Hand");
  GLADE_HOOKUP_OBJECT (winMain, separator25, "separator25");
  GLADE_HOOKUP_OBJECT (winMain, button3LinkBrush, "button3LinkBrush");
  GLADE_HOOKUP_OBJECT (winMain, button3CopyBrush, "button3CopyBrush");
  GLADE_HOOKUP_OBJECT (winMain, button3NABrush, "button3NABrush");
  GLADE_HOOKUP_OBJECT (winMain, separator18, "separator18");
  GLADE_HOOKUP_OBJECT (winMain, optionsProgressiveBG, "optionsProgressiveBG");
  GLADE_HOOKUP_OBJECT (winMain, optionsPrintRuling, "optionsPrintRuling");
  GLADE_HOOKUP_OBJECT (winMain, optionsLegacyPDFExport, "optionsLegacyPDFExport");
  GLADE_HOOKUP_OBJECT (winMain, optionsLayersPDFExport, "optionsLayersPDFExport");
  GLADE_HOOKUP_OBJECT (winMain, optionsAutoloadPdfXoj, "optionsAutoloadPdfXoj");
  GLADE_HOOKUP_OBJECT (winMain, optionsAutosaveXoj, "optionsAutosaveXoj");
  GLADE_HOOKUP_OBJECT (winMain, optionsLeftHanded, "optionsLeftHanded");
  GLADE_HOOKUP_OBJECT (winMain, optionsShortenMenus, "optionsShortenMenus");
  GLADE_HOOKUP_OBJECT (winMain, optionsPenCursor, "optionsPenCursor");
  GLADE_HOOKUP_OBJECT (winMain, separator21, "separator21");
  GLADE_HOOKUP_OBJECT (winMain, optionsAutoSavePrefs, "optionsAutoSavePrefs");
  GLADE_HOOKUP_OBJECT (winMain, optionsSavePreferences, "optionsSavePreferences");
  GLADE_HOOKUP_OBJECT (winMain, menuHelp, "menuHelp");
  GLADE_HOOKUP_OBJECT (winMain, menuHelp_menu, "menuHelp_menu");
  GLADE_HOOKUP_OBJECT (winMain, helpIndex, "helpIndex");
  GLADE_HOOKUP_OBJECT (winMain, helpAbout, "helpAbout");
  GLADE_HOOKUP_OBJECT (winMain, toolbarMain, "toolbarMain");
  GLADE_HOOKUP_OBJECT (winMain, saveButton, "saveButton");
  GLADE_HOOKUP_OBJECT (winMain, newButton, "newButton");
  GLADE_HOOKUP_OBJECT (winMain, openButton, "openButton");
  GLADE_HOOKUP_OBJECT (winMain, toolitem11, "toolitem11");
  GLADE_HOOKUP_OBJECT (winMain, vseparator1, "vseparator1");
  GLADE_HOOKUP_OBJECT (winMain, buttonCut, "buttonCut");
  GLADE_HOOKUP_OBJECT (winMain, buttonCopy, "buttonCopy");
  GLADE_HOOKUP_OBJECT (winMain, buttonPaste, "buttonPaste");
  GLADE_HOOKUP_OBJECT (winMain, toolitem12, "toolitem12");
  GLADE_HOOKUP_OBJECT (winMain, vseparator2, "vseparator2");
  GLADE_HOOKUP_OBJECT (winMain, buttonUndo, "buttonUndo");
  GLADE_HOOKUP_OBJECT (winMain, buttonRedo, "buttonRedo");
  GLADE_HOOKUP_OBJECT (winMain, toolitem13, "toolitem13");
  GLADE_HOOKUP_OBJECT (winMain, vseparator3, "vseparator3");
  GLADE_HOOKUP_OBJECT (winMain, buttonFirstPage, "buttonFirstPage");
  GLADE_HOOKUP_OBJECT (winMain, buttonPreviousPage, "buttonPreviousPage");
  GLADE_HOOKUP_OBJECT (winMain, buttonNextPage, "buttonNextPage");
  GLADE_HOOKUP_OBJECT (winMain, buttonLastPage, "buttonLastPage");
  GLADE_HOOKUP_OBJECT (winMain, toolitem14, "toolitem14");
  GLADE_HOOKUP_OBJECT (winMain, vseparator4, "vseparator4");
  GLADE_HOOKUP_OBJECT (winMain, buttonZoomOut, "buttonZoomOut");
  GLADE_HOOKUP_OBJECT (winMain, buttonPageWidth, "buttonPageWidth");
  GLADE_HOOKUP_OBJECT (winMain, buttonZoomIn, "buttonZoomIn");
  GLADE_HOOKUP_OBJECT (winMain, buttonNormalSize, "buttonNormalSize");
  GLADE_HOOKUP_OBJECT (winMain, buttonZoomSet, "buttonZoomSet");
  GLADE_HOOKUP_OBJECT (winMain, buttonFullscreen, "buttonFullscreen");
  GLADE_HOOKUP_OBJECT (winMain, toolbarPen, "toolbarPen");
  GLADE_HOOKUP_OBJECT (winMain, buttonPen, "buttonPen");
  GLADE_HOOKUP_OBJECT (winMain, buttonEraser, "buttonEraser");
  GLADE_HOOKUP_OBJECT (winMain, buttonHighlighter, "buttonHighlighter");
  GLADE_HOOKUP_OBJECT (winMain, buttonText, "buttonText");
  GLADE_HOOKUP_OBJECT (winMain, buttonImage, "buttonImage");
  GLADE_HOOKUP_OBJECT (winMain, buttonReco, "buttonReco");
  GLADE_HOOKUP_OBJECT (winMain, buttonRuler, "buttonRuler");
  GLADE_HOOKUP_OBJECT (winMain, toolitem15, "toolitem15");
  GLADE_HOOKUP_OBJECT (winMain, vseparator5, "vseparator5");
  GLADE_HOOKUP_OBJECT (winMain, buttonSelectRegion, "buttonSelectRegion");
  GLADE_HOOKUP_OBJECT (winMain, buttonSelectRectangle, "buttonSelectRectangle");
  GLADE_HOOKUP_OBJECT (winMain, buttonVerticalSpace, "buttonVerticalSpace");
  GLADE_HOOKUP_OBJECT (winMain, buttonHand, "buttonHand");
  GLADE_HOOKUP_OBJECT (winMain, toolitem16, "toolitem16");
  GLADE_HOOKUP_OBJECT (winMain, vseparator6, "vseparator6");
  GLADE_HOOKUP_OBJECT (winMain, buttonToolDefault, "buttonToolDefault");
  GLADE_HOOKUP_OBJECT (winMain, buttonDefaultPen, "buttonDefaultPen");
  GLADE_HOOKUP_OBJECT (winMain, toolitem18, "toolitem18");
  GLADE_HOOKUP_OBJECT (winMain, vseparator8, "vseparator8");
  GLADE_HOOKUP_OBJECT (winMain, buttonFine, "buttonFine");
  GLADE_HOOKUP_OBJECT (winMain, buttonMedium, "buttonMedium");
  GLADE_HOOKUP_OBJECT (winMain, buttonThick, "buttonThick");
  GLADE_HOOKUP_OBJECT (winMain, buttonThicknessOther, "buttonThicknessOther");
  GLADE_HOOKUP_OBJECT (winMain, toolitem17, "toolitem17");
  GLADE_HOOKUP_OBJECT (winMain, vseparator7, "vseparator7");
  GLADE_HOOKUP_OBJECT (winMain, buttonBlack, "buttonBlack");
  GLADE_HOOKUP_OBJECT (winMain, buttonBlue, "buttonBlue");
  GLADE_HOOKUP_OBJECT (winMain, buttonRed, "buttonRed");
  GLADE_HOOKUP_OBJECT (winMain, buttonGreen, "buttonGreen");
  GLADE_HOOKUP_OBJECT (winMain, buttonGray, "buttonGray");
  GLADE_HOOKUP_OBJECT (winMain, buttonLightBlue, "buttonLightBlue");
  GLADE_HOOKUP_OBJECT (winMain, buttonLightGreen, "buttonLightGreen");
  GLADE_HOOKUP_OBJECT (winMain, buttonMagenta, "buttonMagenta");
  GLADE_HOOKUP_OBJECT (winMain, buttonOrange, "buttonOrange");
  GLADE_HOOKUP_OBJECT (winMain, buttonYellow, "buttonYellow");
  GLADE_HOOKUP_OBJECT (winMain, buttonWhite, "buttonWhite");
  GLADE_HOOKUP_OBJECT (winMain, buttonColorOther, "buttonColorOther");
  GLADE_HOOKUP_OBJECT (winMain, toolitem22, "toolitem22");
  GLADE_HOOKUP_OBJECT (winMain, buttonColorChooser, "buttonColorChooser");
  GLADE_HOOKUP_OBJECT (winMain, toolitem21, "toolitem21");
  GLADE_HOOKUP_OBJECT (winMain, vseparator10, "vseparator10");
  GLADE_HOOKUP_OBJECT (winMain, toolitem20, "toolitem20");
  GLADE_HOOKUP_OBJECT (winMain, fontButton, "fontButton");
  GLADE_HOOKUP_OBJECT (winMain, scrolledwindowMain, "scrolledwindowMain");
  GLADE_HOOKUP_OBJECT (winMain, hbox1, "hbox1");
  GLADE_HOOKUP_OBJECT (winMain, labelPage, "labelPage");
  GLADE_HOOKUP_OBJECT (winMain, spinPageNo, "spinPageNo");
  GLADE_HOOKUP_OBJECT (winMain, labelNumpages, "labelNumpages");
  GLADE_HOOKUP_OBJECT (winMain, vseparator9, "vseparator9");
  GLADE_HOOKUP_OBJECT (winMain, labelLayer, "labelLayer");
  GLADE_HOOKUP_OBJECT (winMain, comboLayer, "comboLayer");
  GLADE_HOOKUP_OBJECT (winMain, statusbar, "statusbar");
  GLADE_HOOKUP_OBJECT_NO_REF (winMain, tooltips, "tooltips");

  gtk_window_add_accel_group (GTK_WINDOW (winMain), accel_group);

  return winMain;
}

GtkWidget*
create_papersizeDialog (void)
{
  GtkWidget *papersizeDialog;
  GtkWidget *dialog_vbox1;
  GtkWidget *hbox2;
  GtkWidget *labelStdSizes;
  GtkWidget *comboStdSizes;
  GtkWidget *hbox3;
  GtkWidget *labelWidth;
  GtkWidget *entryWidth;
  GtkWidget *labelHeight;
  GtkWidget *entryHeight;
  GtkWidget *comboUnit;
  GtkWidget *dialog_action_area1;
  GtkWidget *cancelbutton1;
  GtkWidget *okbutton1;

  papersizeDialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (papersizeDialog), _("Set Paper Size"));
  gtk_window_set_modal (GTK_WINDOW (papersizeDialog), TRUE);
  gtk_window_set_resizable (GTK_WINDOW (papersizeDialog), FALSE);
  gtk_window_set_type_hint (GTK_WINDOW (papersizeDialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox1 = GTK_DIALOG (papersizeDialog)->vbox;
  gtk_widget_show (dialog_vbox1);

  hbox2 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox2);
  gtk_box_pack_start (GTK_BOX (dialog_vbox1), hbox2, TRUE, TRUE, 10);

  labelStdSizes = gtk_label_new (_("Standard paper sizes:"));
  gtk_widget_show (labelStdSizes);
  gtk_box_pack_start (GTK_BOX (hbox2), labelStdSizes, FALSE, FALSE, 0);
  gtk_misc_set_padding (GTK_MISC (labelStdSizes), 10, 0);

  comboStdSizes = gtk_combo_box_new_text ();
  gtk_widget_show (comboStdSizes);
  gtk_box_pack_start (GTK_BOX (hbox2), comboStdSizes, TRUE, TRUE, 5);
  gtk_combo_box_append_text (GTK_COMBO_BOX (comboStdSizes), _("A4"));
  gtk_combo_box_append_text (GTK_COMBO_BOX (comboStdSizes), _("A4 (landscape)"));
  gtk_combo_box_append_text (GTK_COMBO_BOX (comboStdSizes), _("A5"));
  gtk_combo_box_append_text (GTK_COMBO_BOX (comboStdSizes), _("US Letter"));
  gtk_combo_box_append_text (GTK_COMBO_BOX (comboStdSizes), _("US Letter (landscape)"));
  gtk_combo_box_append_text (GTK_COMBO_BOX (comboStdSizes), _("Custom"));

  hbox3 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox3);
  gtk_box_pack_start (GTK_BOX (dialog_vbox1), hbox3, TRUE, TRUE, 8);

  labelWidth = gtk_label_new (_("Width:"));
  gtk_widget_show (labelWidth);
  gtk_box_pack_start (GTK_BOX (hbox3), labelWidth, FALSE, FALSE, 10);

  entryWidth = gtk_entry_new ();
  gtk_widget_show (entryWidth);
  gtk_box_pack_start (GTK_BOX (hbox3), entryWidth, TRUE, TRUE, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (entryWidth), 5);

  labelHeight = gtk_label_new (_("Height:"));
  gtk_widget_show (labelHeight);
  gtk_box_pack_start (GTK_BOX (hbox3), labelHeight, FALSE, FALSE, 10);

  entryHeight = gtk_entry_new ();
  gtk_widget_show (entryHeight);
  gtk_box_pack_start (GTK_BOX (hbox3), entryHeight, TRUE, TRUE, 0);
  gtk_entry_set_width_chars (GTK_ENTRY (entryHeight), 5);

  comboUnit = gtk_combo_box_new_text ();
  gtk_widget_show (comboUnit);
  gtk_box_pack_start (GTK_BOX (hbox3), comboUnit, FALSE, TRUE, 8);
  gtk_combo_box_append_text (GTK_COMBO_BOX (comboUnit), _("cm"));
  gtk_combo_box_append_text (GTK_COMBO_BOX (comboUnit), _("in"));
  gtk_combo_box_append_text (GTK_COMBO_BOX (comboUnit), _("pixels"));
  gtk_combo_box_append_text (GTK_COMBO_BOX (comboUnit), _("points"));

  dialog_action_area1 = GTK_DIALOG (papersizeDialog)->action_area;
  gtk_widget_show (dialog_action_area1);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area1), GTK_BUTTONBOX_END);

  cancelbutton1 = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancelbutton1);
  gtk_dialog_add_action_widget (GTK_DIALOG (papersizeDialog), cancelbutton1, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancelbutton1, GTK_CAN_DEFAULT);

  okbutton1 = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (okbutton1);
  gtk_dialog_add_action_widget (GTK_DIALOG (papersizeDialog), okbutton1, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (okbutton1, GTK_CAN_DEFAULT);

  g_signal_connect ((gpointer) comboStdSizes, "changed",
                    G_CALLBACK (on_comboStdSizes_changed),
                    NULL);
  g_signal_connect ((gpointer) entryWidth, "changed",
                    G_CALLBACK (on_entryWidth_changed),
                    NULL);
  g_signal_connect ((gpointer) entryHeight, "changed",
                    G_CALLBACK (on_entryHeight_changed),
                    NULL);
  g_signal_connect ((gpointer) comboUnit, "changed",
                    G_CALLBACK (on_comboUnit_changed),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (papersizeDialog, papersizeDialog, "papersizeDialog");
  GLADE_HOOKUP_OBJECT_NO_REF (papersizeDialog, dialog_vbox1, "dialog_vbox1");
  GLADE_HOOKUP_OBJECT (papersizeDialog, hbox2, "hbox2");
  GLADE_HOOKUP_OBJECT (papersizeDialog, labelStdSizes, "labelStdSizes");
  GLADE_HOOKUP_OBJECT (papersizeDialog, comboStdSizes, "comboStdSizes");
  GLADE_HOOKUP_OBJECT (papersizeDialog, hbox3, "hbox3");
  GLADE_HOOKUP_OBJECT (papersizeDialog, labelWidth, "labelWidth");
  GLADE_HOOKUP_OBJECT (papersizeDialog, entryWidth, "entryWidth");
  GLADE_HOOKUP_OBJECT (papersizeDialog, labelHeight, "labelHeight");
  GLADE_HOOKUP_OBJECT (papersizeDialog, entryHeight, "entryHeight");
  GLADE_HOOKUP_OBJECT (papersizeDialog, comboUnit, "comboUnit");
  GLADE_HOOKUP_OBJECT_NO_REF (papersizeDialog, dialog_action_area1, "dialog_action_area1");
  GLADE_HOOKUP_OBJECT (papersizeDialog, cancelbutton1, "cancelbutton1");
  GLADE_HOOKUP_OBJECT (papersizeDialog, okbutton1, "okbutton1");

  return papersizeDialog;
}

GtkWidget*
create_aboutDialog (void)
{
  GtkWidget *aboutDialog;
  GtkWidget *dialog_vbox2;
  GtkWidget *image387;
  GtkWidget *labelTitle;
  GtkWidget *labelInfo;
  GtkWidget *dialog_action_area2;
  GtkWidget *closebutton1;

  aboutDialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (aboutDialog), _("About Xournal"));
  gtk_window_set_resizable (GTK_WINDOW (aboutDialog), FALSE);
  gtk_window_set_type_hint (GTK_WINDOW (aboutDialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox2 = GTK_DIALOG (aboutDialog)->vbox;
  gtk_widget_show (dialog_vbox2);

  image387 = create_pixmap (aboutDialog, "xournal.png");
  gtk_widget_show (image387);
  gtk_box_pack_start (GTK_BOX (dialog_vbox2), image387, FALSE, TRUE, 12);

  labelTitle = gtk_label_new (_("Xournal"));
  gtk_widget_show (labelTitle);
  gtk_box_pack_start (GTK_BOX (dialog_vbox2), labelTitle, FALSE, FALSE, 3);
  gtk_label_set_justify (GTK_LABEL (labelTitle), GTK_JUSTIFY_CENTER);

  labelInfo = gtk_label_new (_("Written by Denis Auroux\nand other contributors\n       http://xournal.sourceforge.net/       "));
  gtk_widget_show (labelInfo);
  gtk_box_pack_start (GTK_BOX (dialog_vbox2), labelInfo, FALSE, FALSE, 0);
  gtk_label_set_justify (GTK_LABEL (labelInfo), GTK_JUSTIFY_CENTER);
  gtk_misc_set_padding (GTK_MISC (labelInfo), 20, 10);

  dialog_action_area2 = GTK_DIALOG (aboutDialog)->action_area;
  gtk_widget_show (dialog_action_area2);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area2), GTK_BUTTONBOX_END);

  closebutton1 = gtk_button_new_from_stock ("gtk-close");
  gtk_widget_show (closebutton1);
  gtk_dialog_add_action_widget (GTK_DIALOG (aboutDialog), closebutton1, GTK_RESPONSE_CLOSE);
  GTK_WIDGET_SET_FLAGS (closebutton1, GTK_CAN_DEFAULT);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (aboutDialog, aboutDialog, "aboutDialog");
  GLADE_HOOKUP_OBJECT_NO_REF (aboutDialog, dialog_vbox2, "dialog_vbox2");
  GLADE_HOOKUP_OBJECT (aboutDialog, image387, "image387");
  GLADE_HOOKUP_OBJECT (aboutDialog, labelTitle, "labelTitle");
  GLADE_HOOKUP_OBJECT (aboutDialog, labelInfo, "labelInfo");
  GLADE_HOOKUP_OBJECT_NO_REF (aboutDialog, dialog_action_area2, "dialog_action_area2");
  GLADE_HOOKUP_OBJECT (aboutDialog, closebutton1, "closebutton1");

  return aboutDialog;
}

GtkWidget*
create_zoomDialog (void)
{
  GtkWidget *zoomDialog;
  GtkWidget *dialog_vbox3;
  GtkWidget *vbox1;
  GtkWidget *hbox4;
  GtkWidget *radioZoom;
  GSList *radioZoom_group = NULL;
  GtkObject *spinZoom_adj;
  GtkWidget *spinZoom;
  GtkWidget *label1;
  GtkWidget *radioZoom100;
  GtkWidget *radioZoomWidth;
  GtkWidget *radioZoomHeight;
  GtkWidget *dialog_action_area3;
  GtkWidget *cancelbutton2;
  GtkWidget *button1;
  GtkWidget *button2;

  zoomDialog = gtk_dialog_new ();
  gtk_window_set_title (GTK_WINDOW (zoomDialog), _("Set Zoom"));
  gtk_window_set_modal (GTK_WINDOW (zoomDialog), TRUE);
  gtk_window_set_type_hint (GTK_WINDOW (zoomDialog), GDK_WINDOW_TYPE_HINT_DIALOG);

  dialog_vbox3 = GTK_DIALOG (zoomDialog)->vbox;
  gtk_widget_show (dialog_vbox3);

  vbox1 = gtk_vbox_new (FALSE, 2);
  gtk_widget_show (vbox1);
  gtk_box_pack_start (GTK_BOX (dialog_vbox3), vbox1, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (vbox1), 8);

  hbox4 = gtk_hbox_new (FALSE, 0);
  gtk_widget_show (hbox4);
  gtk_box_pack_start (GTK_BOX (vbox1), hbox4, FALSE, FALSE, 0);

  radioZoom = gtk_radio_button_new_with_mnemonic (NULL, _("Zoom: "));
  gtk_widget_show (radioZoom);
  gtk_box_pack_start (GTK_BOX (hbox4), radioZoom, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (radioZoom), 4);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radioZoom), radioZoom_group);
  radioZoom_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radioZoom));

  spinZoom_adj = gtk_adjustment_new (100, 10, 1500, 5, 0, 0);
  spinZoom = gtk_spin_button_new (GTK_ADJUSTMENT (spinZoom_adj), 1, 0);
  gtk_widget_show (spinZoom);
  gtk_box_pack_start (GTK_BOX (hbox4), spinZoom, FALSE, TRUE, 5);
  gtk_spin_button_set_numeric (GTK_SPIN_BUTTON (spinZoom), TRUE);

  label1 = gtk_label_new (_("%"));
  gtk_widget_show (label1);
  gtk_box_pack_start (GTK_BOX (hbox4), label1, FALSE, TRUE, 0);
  gtk_misc_set_alignment (GTK_MISC (label1), 0.48, 0.5);

  radioZoom100 = gtk_radio_button_new_with_mnemonic (NULL, _("Normal size (100%)"));
  gtk_widget_show (radioZoom100);
  gtk_box_pack_start (GTK_BOX (vbox1), radioZoom100, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (radioZoom100), 4);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radioZoom100), radioZoom_group);
  radioZoom_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radioZoom100));

  radioZoomWidth = gtk_radio_button_new_with_mnemonic (NULL, _("Page Width"));
  gtk_widget_show (radioZoomWidth);
  gtk_box_pack_start (GTK_BOX (vbox1), radioZoomWidth, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (radioZoomWidth), 4);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radioZoomWidth), radioZoom_group);
  radioZoom_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radioZoomWidth));

  radioZoomHeight = gtk_radio_button_new_with_mnemonic (NULL, _("Page Height"));
  gtk_widget_show (radioZoomHeight);
  gtk_box_pack_start (GTK_BOX (vbox1), radioZoomHeight, FALSE, FALSE, 0);
  gtk_container_set_border_width (GTK_CONTAINER (radioZoomHeight), 4);
  gtk_radio_button_set_group (GTK_RADIO_BUTTON (radioZoomHeight), radioZoom_group);
  radioZoom_group = gtk_radio_button_get_group (GTK_RADIO_BUTTON (radioZoomHeight));

  dialog_action_area3 = GTK_DIALOG (zoomDialog)->action_area;
  gtk_widget_show (dialog_action_area3);
  gtk_button_box_set_layout (GTK_BUTTON_BOX (dialog_action_area3), GTK_BUTTONBOX_END);

  cancelbutton2 = gtk_button_new_from_stock ("gtk-cancel");
  gtk_widget_show (cancelbutton2);
  gtk_dialog_add_action_widget (GTK_DIALOG (zoomDialog), cancelbutton2, GTK_RESPONSE_CANCEL);
  GTK_WIDGET_SET_FLAGS (cancelbutton2, GTK_CAN_DEFAULT);

  button1 = gtk_button_new_from_stock ("gtk-apply");
  gtk_widget_show (button1);
  gtk_dialog_add_action_widget (GTK_DIALOG (zoomDialog), button1, GTK_RESPONSE_APPLY);
  GTK_WIDGET_SET_FLAGS (button1, GTK_CAN_DEFAULT);

  button2 = gtk_button_new_from_stock ("gtk-ok");
  gtk_widget_show (button2);
  gtk_dialog_add_action_widget (GTK_DIALOG (zoomDialog), button2, GTK_RESPONSE_OK);
  GTK_WIDGET_SET_FLAGS (button2, GTK_CAN_DEFAULT);

  g_signal_connect ((gpointer) radioZoom, "toggled",
                    G_CALLBACK (on_radioZoom_toggled),
                    NULL);
  g_signal_connect ((gpointer) spinZoom, "value_changed",
                    G_CALLBACK (on_spinZoom_value_changed),
                    NULL);
  g_signal_connect ((gpointer) radioZoom100, "toggled",
                    G_CALLBACK (on_radioZoom100_toggled),
                    NULL);
  g_signal_connect ((gpointer) radioZoomWidth, "toggled",
                    G_CALLBACK (on_radioZoomWidth_toggled),
                    NULL);
  g_signal_connect ((gpointer) radioZoomHeight, "toggled",
                    G_CALLBACK (on_radioZoomHeight_toggled),
                    NULL);

  /* Store pointers to all widgets, for use by lookup_widget(). */
  GLADE_HOOKUP_OBJECT_NO_REF (zoomDialog, zoomDialog, "zoomDialog");
  GLADE_HOOKUP_OBJECT_NO_REF (zoomDialog, dialog_vbox3, "dialog_vbox3");
  GLADE_HOOKUP_OBJECT (zoomDialog, vbox1, "vbox1");
  GLADE_HOOKUP_OBJECT (zoomDialog, hbox4, "hbox4");
  GLADE_HOOKUP_OBJECT (zoomDialog, radioZoom, "radioZoom");
  GLADE_HOOKUP_OBJECT (zoomDialog, spinZoom, "spinZoom");
  GLADE_HOOKUP_OBJECT (zoomDialog, label1, "label1");
  GLADE_HOOKUP_OBJECT (zoomDialog, radioZoom100, "radioZoom100");
  GLADE_HOOKUP_OBJECT (zoomDialog, radioZoomWidth, "radioZoomWidth");
  GLADE_HOOKUP_OBJECT (zoomDialog, radioZoomHeight, "radioZoomHeight");
  GLADE_HOOKUP_OBJECT_NO_REF (zoomDialog, dialog_action_area3, "dialog_action_area3");
  GLADE_HOOKUP_OBJECT (zoomDialog, cancelbutton2, "cancelbutton2");
  GLADE_HOOKUP_OBJECT (zoomDialog, button1, "button1");
  GLADE_HOOKUP_OBJECT (zoomDialog, button2, "button2");

  return zoomDialog;
}

